
/*
  Natjecanje timova studenata informaticara hrvatskih sveucilista 2005
  Prvo natjecanje - Zadatak FLIPER

  Opis algoritma:
  Zadatak rjesavamo tako da novu prepreku probamo postaviti na svaku mogucu 
  slobodnu poziciju. Dodavanjem nove prepreke se moze doci od tocke A do tocke B 
  u jednom od tri slucaja: (1) iz ove pozicije se, krenuvsi u nekom smjeru, 
  dodje do A i krenuvsi okomito na taj smjer dodje do B, (2) od A do B se moze 
  doci i bez nove prepreke, putem koji ne prolazi kroz ovu poziciju, (3) od A do 
  B se moze doci i bez nove prepreke, put prolazi kroz ovu poziciju, te postoji 
  neki ciklus koji prolazi kroz ovu poziciju.
  Da bi rjesenje bilo dovoljno brzo potrebno je unaprijed za svaku mogucu
  poziciju i smjer izracunati gdje zavrsimo ako krenemo iz te pozicije u tom 
  smjeru.
*/

#include <iostream>
#include <cstring>

using namespace std;

const int MAX=1000;
const int dirx[4]={1, 0, -1, 0};
const int diry[4]={0, -1, 0, 1};
const int skrt[3][4]={ {0, 1, 2, 3}, {3, 2, 1, 0}, {1, 0, 3, 2} };

int n, m, k;
int ax, ay, as;
int bx, by, bs;

int zid[MAX][MAX];

unsigned char gotovo[MAX][MAX][4];
unsigned char doA[MAX][MAX][4];
unsigned char doB[MAX][MAX][4];
int ciklus[MAX][MAX][4];
int duljina[MAX][MAX][4];

int best;
int bestx, besty, bests;

void citaj_ulaz (void)
{
        cin >> n >> m >> k;
        cin >> ax >> ay >> as; ax--, ay--, as--;
        cin >> bx >> by >> bs; bx--, by--, bs--;
        memset(zid, 0, sizeof zid);
        for (int i=0; i<k-1; i++)
        {
                int x, y;
                cin >> x >> y;
                cin >> zid[x-1][y-1];
        }
}

void naprijed (int &x, int &y, int &s)
{
        s=skrt[zid[x][y]][s];
        x+=dirx[s];
        y+=diry[s];
}

int unutra (int x, int y)
{
        return x>=0 && x<n && y>=0 && y<m;
}

void vozi (int x, int y, int s)
{
        int xx=x;
        int yy=y;
        int ss=s;
        int korak=0;

        while (unutra(xx, yy) && !gotovo[xx][yy][ss])
        {
                korak++;
                gotovo[xx][yy][ss]=1;
                naprijed(xx, yy, ss);
        }

        if (unutra(xx, yy) && gotovo[xx][yy][ss]==1)
        {
                ciklus[x][y][s]=korak;
        }
        else if (unutra(xx, yy))
        {
                doA[x][y][s]=doA[xx][yy][ss];
                doB[x][y][s]=doB[xx][yy][ss];
                ciklus[x][y][s]=ciklus[xx][yy][ss];
                duljina[x][y][s]=duljina[xx][yy][ss]+korak;
        }
        else if (xx==ax+dirx[(as+2)%4] && yy==ay+diry[(as+2)%4])
        {
                doA[x][y][s]=1;
                duljina[x][y][s]=korak;
        }
        else if (xx==bx+dirx[(bs+2)%4] && yy==by+diry[(bs+2)%4])
        {
                doB[x][y][s]=1;
                duljina[x][y][s]=korak;
        }

        xx=x;
        yy=y;
        ss=s;
        korak=0;
        while (unutra(xx, yy) && gotovo[xx][yy][ss]==1)
        {
                gotovo[xx][yy][ss]=2;
                doA[xx][yy][ss]=doA[x][y][s];
                doB[xx][yy][ss]=doB[x][y][s];
                ciklus[xx][yy][ss]=ciklus[x][y][s];
                duljina[xx][yy][ss]=duljina[x][y][s]-korak;
                naprijed(xx, yy, ss);
                korak++;
        }
}

void probaj (int x, int y, int s)
{
        if (zid[x][y]) return ;

        // mozda se putevi iz A i B ovdje sjeku pod pravim kutem
        for (int i=0; i<4; i++)
                if (doA[x][y][i] && doB[x][y][skrt[s][(i+2)%4]])
                {
                        int temp=duljina[x][y][i]+duljina[x][y][skrt[s][(i+2)%4]]-1;
                        if (temp>=best) continue ;
                        best=temp;
                        bestx=x;
                        besty=y;
                        bests=s;
                }

        // mozda se moze direktno doci od A do B, a ovdje je slobodno polje
        if (doB[ax][ay][as])
        {
                int ok=1;
                for (int i=0; i<4; i++)
                        if (doA[x][y][i]) ok=0;
                if (ok && duljina[ax][ay][as]<best)
                {
                        best=duljina[ax][ay][as];
                        bestx=x;
                        besty=y;
                        bests=s;
                }
        }

        // mozda se moze direktno doci od A do B a ovdje taj put sjece neki ciklus
        if (doB[ax][ay][as])
                for (int i=0; i<4; i++)
                        if (ciklus[x][y][i] && doA[x][y][(i+1)%4] && doB[x][y][(i+3)%4])
                        {
                                int temp=ciklus[x][y][i]+duljina[x][y][(i+1)%4]+duljina[x][y][(i+3)%4]-1;
                                if (temp>=best) continue ;
                                best=temp;
                                bestx=x;
                                besty=y;
                                bests=s;
                        }
}

void rijesi (void)
{
        memset(gotovo, 0, sizeof gotovo);
        memset(doA, 0, sizeof doA);
        memset(doB, 0, sizeof doB);
        memset(ciklus, 0, sizeof ciklus);
        memset(duljina, 0, sizeof duljina);

        for (int i=0; i<n; i++)
                for (int j=0; j<m; j++)
                        for (int k=0; k<4; k++)
                                if (!gotovo[i][j][k])
                                        vozi(i, j, k);

        best=(1<<30);

        for (int i=0; i<n; i++)
                for (int j=0; j<m; j++)
                        for (int k=1; k<=2; k++)
                                probaj(i, j, k);
}

void ispisi_rjesenje (void)
{
        cout << bestx+1 << " " << besty+1 << " " << bests << endl;
}

int main (void)
{
        citaj_ulaz();
        rijesi();
        ispisi_rjesenje();
        return 0;
}
