
/*
  Natjecanje timova studenata informaticara hrvatskih sveucilista 2005
  Prvo natjecanje - Zadatak MEMORIJA

  Opis algoritma:
  Zadatak rjesavamo na sljedeci nacin: Stanje memorije u svakom trenutku mozemo 
  zamisliti kao niz intervala, gdje svaki interval predstavlja uzastopne 
  memorijske lokacije koje su ili sve slobodne ili sve zauzete. Svi intervali 
  su maksimalni, odnosni svaka dva susjedna intervala su uvijek razlicite boje.
  Naredba tipa 1 ili 2 brise i dodaje nekoliko intervala. Razlikujemo 4 slucaja: 
  1. novi interval razbija neki trenutni intervala na tri dijela, 2. novi 
  interval se spaja sa prethodim intervalom, 3. novi interval se spaja sa 
  sljedecim intervalom, 4. novi interval se spaja i sa prethodnim i sa sljedecim 
  intervalom. U svakom ova 4 slucaja pobrisat cemo najvise tri intervala i 
  dodati najvise tri nova intervala.
  Da bi rjesenje bilo dovoljno efikasno potrebno je koristiti strukturu podataka 
  koja omogucuje (1) brzo trazenje intervala koji sadrzi zadani element, (2) 
  brzo brisanje intervala, (3) brzo dodavanje intervala, (4) brzo odredjivanje 
  najveceg slobodnog intervala.
  Ovo rjesenje koristi koristi strukturu podataka map koja cuva podatke o 
  intervalima (mem[c] je boja intervala koji pocinje na c) i multiset koji cuva 
  duljine svih slobodnih intervala.
*/

#include <iostream>
#include <map>
#include <set>

using namespace std;

typedef map<int, int> M;
typedef M::iterator Mi;
typedef multiset<int> S;

const int MAXM=200000;

int n;
int m;
int c[MAXM];
int a[MAXM];
int k[MAXM];

M mem;
S naj;

void citaj_ulaz (void)
{
        cin >> n;
        cin >> m;
        for (int i=0; i<m; i++)
        {
                cin >> c[i];
                if (c[i]!=3) cin >> a[i] >> k[i];
        }
}

void rijesi (void)
{
        mem[0]=1;
        mem[1]=0;
        mem[n+1]=1;
        naj.insert(0);
        naj.insert(n);
        for (int i=0; i<m; i++)
        {
                if (c[i]==3)
                {
                        cout << *(naj.rbegin()) << endl;
                        continue ;
                }

                Mi left=--mem.upper_bound(a[i]);
                Mi right=--mem.upper_bound(a[i]+k[i]);

                for (Mi p=left; p!=mem.end() ; p++)
                {
                        Mi q=p; q--;
                        if ((*p).first<a[i]) continue ;
                        if ((*q).first>a[i]+k[i]) break ;
                        if ((*q).second==0) naj.erase(naj.find((*p).first-(*q).first));
                }

                if ((*left).first==a[i]) mem.erase(left--);
                else mem[a[i]]=c[i]==1?1:0;

                if ((*right).first==a[i]+k[i]) mem.erase(right);
                else mem[a[i]+k[i]]=c[i]==1?0:1;

                for (Mi p=left; p!=mem.end(); p++)
                {
                        Mi q=p; q--;
                        if ((*p).first<a[i]) continue ;
                        if ((*q).first>a[i]+k[i]) break ;
                        if ((*q).second==0) naj.insert((*p).first-(*q).first);
                }
        }
}

int main (void)
{
        citaj_ulaz();
        rijesi();
        return 0;
}
