
/*
  Natjecanje timova studenata informaticara hrvatskih sveucilista 2005
  Drugo natjecanje - Zadatak EUROPA

  Opis algoritma:
  Zadatak rjesavamo svodjenjem na problem najveceg toka u mrezi.
  Za svaki par (stara drzava A, nova drzava B) najprije iz ogranicenja odredimo
  minimalnu i maksimalnu kolicu novca koji A daje B. U prvom koraku se rjesavamo
  donjih granica tako da zabiljezimo da je A vec dala B tu minimalnu kolicinu
  novaca, istovremeno smanjujuci odgovarajuce sume za istu vrijednost.
  U drugom koraku konstruiramo transportnu mrezu koja se sastoji od: izvora,
  starih drzava, novih drzava i ponora. Kapacitet veze od izvora do neke stare
  drzave odgovara sumi novaca koji ta drzava jos mora dati, kapacitet veze
  izmedju stare i nove drzave odgovara razlici izmedju odgovarajuce gornje i
  donje granice, kapacitet veze izmedju nove drzave i ponora odgovara sume
  novaca koji ta drzava jos mora primiti.
  U ovoj mrezi trazimo najveci tok Ford-Fulkersonovim algoritmom i iz njega
  jednostavno konstruiramo rjesenje.
*/

#include <stdio.h>

#define MAXSTARIH	200
#define MAXNOVIH	20
#define INF             100000000
#define MAXG            (MAXNOVIH+MAXSTARIH+2)
#define QSIZE           MAXG

#define MAX(A, B)       ((A)>(B)?(A):(B))
#define MIN(A, B)       ((A)<(B)?(A):(B))

int kap[MAXG][MAXG];
int interval[MAXSTARIH][MAXNOVIH][2], suma_drzave[MAXSTARIH], suma_podrucja[MAXNOVIH];
int broj_drzava, broj_podrucja;

int q[QSIZE];
int head, tail;

void initq (void) { head=tail=0; }
int empty (void) { return head==tail; }
void push (int a) { q[head++]=a; head%=QSIZE; }
int front (void) { return q[tail]; }
void pop (void) { tail=(tail+1)%QSIZE; }

int increase_flow ( void )
{
	/* bfs */
	int otkud[MAXG];
	int source=0, sink=broj_drzava+broj_podrucja+1;
	int v, susj, flo;

	for (v=source; v<=sink; v++)
		otkud[v]=-1;

        initq();
        push(source); otkud[source]=-2;
	while (!empty())
	{
		v=front();
                pop();
		for (susj=source; susj<=sink; susj++)
			if (otkud[susj]==-1 && kap[v][susj])
			{
				otkud[susj]=v;
				push(susj);
			}		
	}
		
	if (otkud[sink]==-1)
		return 0;
	else
	{
		v=sink, flo=INF;
		while (v!=source)
		{
			flo=MIN(flo, kap[otkud[v]][v]);
			v=otkud[v];
		}
		
		v=sink;
		while (v!=source)
		{
			kap[otkud[v]][v]-=flo; kap[v][otkud[v]]+=flo;
			v=otkud[v];
		}
		
		return 1;
	}
}

int main ( void )
{
        int d, p;
	int broj_uvjeta;

        int drz, pod, limit;
        char znak;

        int drzlo;
        int drzhi;

        int podlo;
        int podhi;

	scanf ("%d%d", &broj_drzava, &broj_podrucja);
	for (d=0; d<broj_drzava; d++)
	{
		scanf ("%d", &suma_drzave[d]);	
		for (p=0; p<broj_podrucja; p++)
			interval[d][p][1]=suma_drzave[d], interval[d][p][0]=0;
	}

	for (p=0; p<broj_podrucja; p++)
	{
		scanf ("%d", &suma_podrucja[p]);	
		for (d=0; d<broj_drzava; d++)
			interval[d][p][1]=MIN(suma_podrucja[p], interval[d][p][1]);
	}


	scanf ("%d", &broj_uvjeta);
	while (broj_uvjeta--)
	{
		scanf ("%d %d %c %d", &drz, &pod, &znak, &limit);
		
		drzlo=drz-1, drzhi=drz;
		if (drz==0) drzlo=0, drzhi=broj_drzava;
		
		podlo=pod-1, podhi=pod;
		if (pod==0) podlo=0, podhi=broj_podrucja;

		for (d=drzlo; d<drzhi; d++)
			for (p=podlo; p<podhi; p++)
				switch (znak)
				{
					case '=' : 
						interval[d][p][1]=interval[d][p][0]=limit; break;
					case '<' : 
						interval[d][p][1]=MIN(interval[d][p][1], limit-1); break;
					case '>' : 
						interval[d][p][0]=MAX(interval[d][p][0], limit+1); break;
				}
	}

	/* napravi graf */
	for (d=0; d<broj_drzava; d++)
		kap[0][d+1]=suma_drzave[d];

	for (p=0; p<broj_podrucja; p++)
		kap[broj_drzava+p+1][broj_drzava+broj_podrucja+1]=suma_podrucja[p];
	
	for (d=0; d<broj_drzava; d++)
		for (p=0; p<broj_podrucja; p++)
		{
			kap[d+1][broj_drzava+p+1]=interval[d][p][1]-interval[d][p][0];
			kap[0][d+1]-=interval[d][p][0];
			kap[broj_drzava+p+1][broj_drzava+broj_podrucja+1]-=interval[d][p][0];
		}

	while (increase_flow());

	for (d=0; d<broj_drzava; d++, printf("\n"))
		for (p=0; p<broj_podrucja; p++, printf(" "))
			printf ("%d", interval[d][p][0]+kap[broj_drzava+p+1][d+1]);

	return 0;
}
