
/*
  Natjecanje timova studenata informaticara hrvatskih sveucilista 2005
  Drugo natjecanje - Zadatak EUROPA

  Opis algoritma:
  Zadatak rjesavamo svodjenjem na problem najveceg toka u mrezi.
  Za svaki par (stara drzava A, nova drzava B) najprije iz ogranicenja odredimo
  minimalnu i maksimalnu kolicu novca koji A daje B. U prvom koraku se rjesavamo
  donjih granica tako da zabiljezimo da je A vec dala B tu minimalnu kolicinu
  novaca, istovremeno smanjujuci odgovarajuce sume za istu vrijednost.
  U drugom koraku konstruiramo transportnu mrezu koja se sastoji od: izvora,
  starih drzava, novih drzava i ponora. Kapacitet veze od izvora do neke stare
  drzave odgovara sumi novaca koji ta drzava jos mora dati, kapacitet veze
  izmedju stare i nove drzave odgovara razlici izmedju odgovarajuce gornje i
  donje granice, kapacitet veze izmedju nove drzave i ponora odgovara sume
  novaca koji ta drzava jos mora primiti.
  U ovoj mrezi trazimo najveci tok Ford-Fulkersonovim algoritmom i iz njega
  jednostavno konstruiramo rjesenje.
*/

#include <iostream>
#include <queue>
#include <cstring>

using namespace std;

struct qelem
{
        int node, last, inc;
        qelem (int n, int l, int i) { node=n, last=l, inc=i; }
        int operator< (const qelem &a) const { return inc<a.inc; }
};

const int MAXM=200;
const int MAXN=20;
const int MAXC=10000;
const int MAXG=MAXM+MAXN+2;

int m, n;
int srow[MAXM];
int scol[MAXN];

int c;
int row[MAXC], col[MAXC], val[MAXC];
char opr[MAXC];

int lo[MAXM][MAXN];
int hi[MAXM][MAXN];

int g;
int cap[MAXG][MAXG];
int flo[MAXG][MAXG];

int how[MAXG];
int naj[MAXG];

void citaj_ulaz (void)
{
        cin >> m >> n;
        for (int i=0; i<m; i++) 
                cin >> srow[i];
        for (int i=0; i<n; i++) 
                cin >> scol[i];
        cin >> c;
        for (int i=0; i<c; i++)
                cin >> row[i] >> col[i] >> ws >> opr[i] >> val[i];
}

void napravi_graf (void)
{
        g=1+m+n+1;
        
        for (int i=0; i<g; i++) 
                for (int j=0; j<g; j++) 
                        cap[i][j]=flo[i][j]=0;

        for (int i=0; i<m; i++)
                cap[0][i+1]=srow[i];

        for (int i=0; i<n; i++) 
                cap[m+1+i][m+n+1]=scol[i];

        for (int i=0; i<m; i++)
                for (int j=0; j<n; j++) 
                        lo[i][j]=0, hi[i][j]=min(srow[i], scol[j]);

        for (int i=0; i<c; i++) 
        {
                int sr;
                int er;
                int sc;
                int ec;

                if (row[i]==0) sr=0, er=m-1;
                else sr=er=row[i]-1;

                if (col[i]==0) sc=0, ec=n-1;
                else sc=ec=col[i]-1;

                for (int j=sr; j<=er; j++)
                        for (int k=sc; k<=ec; k++)
                                if (opr[i]=='>') lo[j][k]=max(lo[j][k], val[i]+1);
                                else if (opr[i]=='<') hi[j][k]=min(hi[j][k], val[i]-1);
                                else lo[j][k]=max(lo[j][k], val[i]), hi[j][k]=min(hi[j][k], val[i]);
        }

        for (int i=0; i<m; i++) 
                for (int j=0; j<n; j++) 
                {
                        cap[i+1][j+1+m]=hi[i][j]-lo[i][j];
                        cap[0][i+1]-=lo[i][j];
                        cap[j+1+m][m+n+1]-=lo[i][j];
                }

}

int trazi (void)
{
        memset(naj, 0, sizeof naj);
        priority_queue<qelem> q;
        q.push(qelem(0, -1, 1<<30));
        while (!q.empty())
        {
                qelem c=q.top();
                q.pop();

                if (naj[c.node]!=0) continue ;
                naj[c.node]=c.inc;
                how[c.node]=c.last;
                if (c.node==g-1) return 1;

                for (int i=0; i<g; i++)
                        if (cap[c.node][i]>flo[c.node][i]) 
                                q.push(qelem(i, c.node, min(c.inc, cap[c.node][i]-flo[c.node][i])));
        }
        return 0;
}

void max_flow (void)
{
        while (trazi())
                for (int i=g-1; i!=0; i=how[i])
                {
                        flo[how[i]][i]+=naj[g-1];
                        flo[i][how[i]]-=naj[g-1];
                }
}


void ispisi_rjesenje (void)
{
        for (int i=0; i<m; i++, cout << endl) 
                for (int j=0; j<n; j++) 
                {
                        cout << lo[i][j]+flo[i+1][j+1+m];
                        if (j!=n-1) cout << " ";
                }
}

int main (void)
{
        citaj_ulaz();
        napravi_graf();
        max_flow();
        ispisi_rjesenje();
        
        return 0;
}
