
/*
  Natjecanje timova studenata informaticara hrvatskih sveucilista 2005
  Drugo natjecanje - Zadatak KURIR

  Opis algoritma:
  Zadatak rjesavamo dinamickim programiranjem. Neka nam N[k][b1][b2][b3][b4][b5] 
  oznacava najkraci moguci put da, krenuvsi iz grada k, isporucimo (za svaki 
  i=1,...,5) bi posiljki za i-ti par gradova i zavrsimo put u pocetnom gradu h. 
  Ovu vrijednost lagano svedemo na jednostavnije potprobleme tako da razmatramo 
  5 slucajeva, gdje i-ti slucaj odgovara scenariju kada iz grada k najprije 
  odemo isporuciti jedan od paketa od grada u[i] do grada v[i]. Kako bi
  implementacija bila efikasna potrebno je unaprijed izracunati najkraci put 
  izmedju svaka dva grada, npr Floydovim algoritmom.

  Doljnje rjesenje implementira opisani algoritam rekurzijom sa memoizacijom, te 
  (radi jednostavnosti) koristi puno vise memorije nego sto stvarno treba.
*/

#include <stdio.h>
#include <string.h>

#define MAXN 100
#define MAXZ 5
#define MAXB 10
#define INF (1<<28)

int n;
int m;
int h;
int d[MAXN][MAXN];

int z;
int u[MAXZ];
int v[MAXZ];
int b[MAXZ];

int N[MAXN*(MAXB+1)*(MAXB+1)*(MAXB+1)*(MAXB+1)*(MAXB+1)];

int min (int a, int b)
{
        return a<b?a:b;
}

void citaj_ulaz (void)
{
        int i;
        int aa, bb, l;

        scanf("%d%d%d", &n, &m, &h);
        h--;
        memset(d, -1, sizeof d);
        for (i=0; i<m; i++)
        {
                scanf("%d%d%d", &aa, &bb, &l);
                aa--, bb--;
                if (d[aa][bb]==-1) d[aa][bb]=d[bb][aa]=l;
                else d[aa][bb]=d[bb][aa]=min(d[aa][bb], l);
        }

        scanf("%d", &z);
        for (i=0; i<z; i++)
        {
                scanf("%d%d%d", &u[i], &v[i], &b[i]);
                u[i]--, v[i]--;
        }
}

void floyd (void)
{
        int i, j, k;

        for (i=0; i<n; i++)
                d[i][i]=0;

        for (i=0; i<n; i++)
                for (j=0; j<n; j++) if (d[j][i]!=-1)
                        for (k=0; k<n; k++) if (d[i][k]!=-1)
                                d[j][k]=min(d[j][k]==-1?(1<<30):d[j][k], d[j][i]+d[i][k]);
}

int nadji (int k)
{
        int arg=0;
        int i;
        int best=INF;

        for (i=0; i<z; i++) arg=arg*(MAXB+1)+b[i];
        if (arg==0) return d[k][h];
        arg=arg*MAXN+k;

        if (N[arg]!=-1) return N[arg];

        for (i=0; i<z; i++)
        {
                if (b[i]==0) continue ;
                b[i]--;
                best=min(best, d[k][u[i]]+d[u[i]][v[i]]+nadji(v[i]));
                b[i]++;
        }

        return N[arg]=best;
}

int main (void)
{
        citaj_ulaz();
        floyd();
        memset(N, -1, sizeof N);
        printf("%d\n", nadji(h));
        return 0;
}
