{---------------------------------------------------------------}
{ ACM ICPC 2005-2006, NEERC                                     }
{ Northern Subregional Contest                                  }
{ St Petersburg, October 29, 2005                               }
{---------------------------------------------------------------}
{ Problem H. Horn Clauses                                       }
{                                                               }
{ Original idea         Dmitri Pavlov                           }
{ Problem statement     Dmitriy Shtukenberg                     }
{ Testset               Andrew Lopatin                          }
{---------------------------------------------------------------}
{ Solution with test checker                                    }
{                                                               }
{ Author                Georgiy Korneev                         }
{---------------------------------------------------------------}

uses
    sysutils;
const
    max_l = 20000;
    letters: set of char = ['A'..'Z'];

type
    plist = ^tlist;
    tlist = record
        next: plist;
        val: longint;
    end;

procedure add(var list: plist; val: longint);
var
    p: plist;
begin
    new(p);
    p.next := list;
    p.val := val;
    list := p;
end;

procedure destroy(var p: plist);
begin
    if p <> nil then begin
        destroy(p.next);
        dispose(p);
        p := nil;
    end;
end;

var
    s: string;
    vars: array [0..max_l] of string;
    vals: array [0..max_l] of boolean;
    cvars: longint;
    cd: longint;
    inant: array [1..max_l] of plist;
    suc, antl: array[1..max_l] of longint;
    ok: boolean;
    head, tail: longint;
    queue: array [1..max_l] of longint;

function getVar(name: string): longint;
var
    i: longint;
begin
    for i := 1 to cVars do begin
        if vars[i] = name then begin
            getVar := i;
            exit;
        end;
    end;
    inc(cVars);
    vars[cVars] := name;
    getVar := cVars;
end;

procedure parse(s: string);
var
    p: longint;

function nextVar(): longint;
var
    v: string;
begin
    while s[p] in letters do begin
        v := v + s[p];
        inc(p);
    end;
    assert(v <> '');
    nextVar := getVar(v)
end;

procedure expect(c: char);
begin
    assert(s[p] = c);
    inc(p);
end;

function test(c: char): boolean;
begin
    test := s[p] = c;
    if (s[p] = c) then inc(p);
end;

procedure parseDisjunct();
var
    v: longint;
begin
    inc(cd);
    expect('(');
    if not test('=') then begin
        repeat
            v := nextVar();
            add(inant[v], cd);
            inc(antl[cd]);
        until not test('&');
        expect('=');
    end;
    expect('>');
    if not test(')') then begin
        suc[cd] := nextVar();
        expect(')');
    end else begin
        suc[cd] := 0;
    end;
end;

begin
    p := 1;
    cd := 0;
    parseDisjunct();
    while test('&') do begin
        parseDisjunct();
    end;
    assert(s[p] = '#');
end;

procedure cleanup();
var
    i: longint;
begin
    for i := 1 to cvars do begin
        destroy(inant[i]);
        vals[i] := false;
    end;
    cVars := 0;

    for i := 1 to cd do begin
        antl[i] := 0;
    end;
end;

procedure setTrue(i: longint);
var
    p: plist;
begin
    if vals[i] then exit;
    vals[i] := true;

    p := inant[i];
    while p <> nil do begin
        dec(antl[p.val]);
        if antl[p.val] = 0 then begin
            inc(head);
            queue[head] := p.val;
        end;
        p := p.next;
    end;
end;

procedure process(i: longint);
begin
    if (suc[i] <> 0) then begin
        setTrue(suc[i]);
    end else begin
        ok := false;
    end;
end;

var
    i: longint;
begin
    assign(input, 'horn.in'); reset(input);
    assign(output, 'horn.out'); rewrite(output);

    while not seekeof do begin
        readln(s);

        parse(s + '#');

        ok := true;

        head := 0;
        tail := 0;
        for i := 1 to cd do begin
            if antl[i] = 0 then begin
                inc(head);
                queue[head] := i;
            end;
        end;

        while ok and (tail < head) do begin
            inc(tail);
            process(queue[tail]);
        end;

        if ok then begin
            for i := 1 to cvars do begin
                if i > 1 then write(', ');
                write(vars[i], '=', vals[i]);
            end;
            writeln;
        end else begin
            writeln('unsatisfiable');
        end;

        cleanup();
    end;

    close(input);
    close(output);
end.