/*---------------------------------------------------------------*/
/* ACM ICPC 2005-2006, NEERC                                     */
/* Northern Subregional Contest                                  */
/* St Petersburg, October 29, 2005                               */
/*---------------------------------------------------------------*/
/* Problem H. Horn Clauses                                       */
/*                                                               */
/* Original idea         Dmitri Pavlov                           */
/* Problem statement     Dmitriy Shtukenberg                     */
/* Testset               Andrew Lopatin                          */
/*---------------------------------------------------------------*/
/* Solution                                                      */
/*                                                               */
/* Author                Mavrin Pavel                            */
/*---------------------------------------------------------------*/

import java.util.*;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.io.FileOutputStream;

public class horn_pm {

    static String s;

    static int ind;

    static Collection<Clause> formula;

    static Map<String, Variable> variables;

    static Queue<Variable> queue;

    static boolean unsatifiable;

    static class Clause {
        public Set<Variable> antecendent = new HashSet<Variable>();
        public Variable succedent;
    }

    static class Variable {
        public String name;
        public boolean value = false;
        public Collection<Clause> usages = new HashSet<Clause>();

        public Variable(String name) {
            this.name = name;
        }

        public void setTrue() {
            if (!value) {
                value = true;
                queue.offer(this);
                for (Clause clause : usages) {
                    clause.antecendent.remove(this);
                    if (clause.antecendent.size() == 0) {
                        if (clause.succedent == null) {
                            unsatifiable = true;
                        } else {
                            clause.succedent.setTrue();
                        }
                    }
                }
            }
        }
    }



    public static void main(String[] args) throws FileNotFoundException {
        Scanner scanner = new Scanner(new File("horn.in"));
        PrintWriter writer = new PrintWriter(new FileOutputStream("horn.out"));

        while (scanner.hasNextLine()) {
            s = scanner.nextLine() + '.';
            ind = 0;
            formula = new ArrayList<Clause>();
            variables = new HashMap<String, Variable>();
            parse();

            queue = new LinkedList<Variable>();

            for (Clause clause : formula) {
                for (Variable v : clause.antecendent) {
                    v.usages.add(clause);
                }
            }

            unsatifiable = false;

            for (Clause clause : formula) {
                if (clause.antecendent.size() == 0) {
                    if (clause.succedent == null) {
                        unsatifiable = true;
                    } else {
                        clause.succedent.setTrue();
                    }
                }
            }

            if (unsatifiable) {
                writer.println("unsatisfiable");
            } else {
                boolean first = true;
                for (Variable v : variables.values()) {
                    if (first) {
                        first = false;
                    } else {
                        writer.print(',');
                    }
                    writer.print(v.name + '=' + v.value);
                }
                writer.println();
            }
        }
        writer.close();
    }

    private static void parse() {
        while (s.charAt(ind) == '(') {
            ind++;
            Clause clause = new Clause();
            while (s.charAt(ind) != '=') {
                Variable v = parseVariable();
                clause.antecendent.add(v);
                if (s.charAt(ind) == '&') ind++;
            }
            ind++;
            assert s.charAt(ind) == '>';
            ind++;
            if (s.charAt(ind) != ')') {
                clause.succedent = parseVariable();
            } else {
                clause.succedent = null;
            }
            assert s.charAt(ind) == ')';
            ind++;
            formula.add(clause);
            if (s.charAt(ind) == '&') ind++;
        }
    }

    private static Variable parseVariable() {
        StringBuffer sb = new StringBuffer();
        while (Character.isLetter(s.charAt(ind))) {
            sb.append(s.charAt(ind));
            ind++;
        }
        String name = sb.toString();
        Variable v = variables.get(name);
        if (v == null) {
            v = new Variable(name);
            variables.put(name, v);
        }
        return v;
    }

}
