/*-------------------------------------------------------------*/
/* ACM ICPC 2005-2006, NEERC                                   */
/* Northern Subregional Contest                                */
/* St Petersburg, October 29, 2005                             */
/*-------------------------------------------------------------*/
/* Problem K. K Best                                           */
/*                                                             */
/* Original idea         Dmitri Pavlov                         */
/* Problem statement     Andrew Stankevich                     */
/* Testset               Andrew Stankevich                     */
/*-------------------------------------------------------------*/
/* Model solution (Java)                                       */
/*                                                             */
/* Author                Andrew Stankevich                     */
/*-------------------------------------------------------------*/

import java.util.Arrays;
import java.io.*;

public class k_as {
    private static final int MAX_VALUE = 1000000;
    private static final int MAX_WEIGHT = 1000000;
    private static final int MAX_VALUE_SUM = 10000000;
    private static final int MAX_WEIGHT_SUM = 10000000;
    private static final double EPS = 1e-20;

    double[] s;
    int n;

    double kth(int l, int r, int k) {
        double x = s[(l + r) / 2];
        int i = l;
        int j = r;
        while (i <= j) {
            while (s[i] > x) i++;
            while (x > s[j]) j--;
            if (i <= j) {
                double t = s[i]; s[i] = s[j]; s[j] = t;
                i++; j--;
            }
        }
        if (k <= j) {
            return kth(l, j, k);
        } else if (i <= k) {
            return kth(i, r, k);
        } else {
            return s[k];
        }
    }

    public void run() throws FileNotFoundException {
        initInput("k.in");
        n = nextInt();
        int k = nextInt();
        int[] v = new int[n];
        int[] w = new int[n];
        int sumw = 0, sumv = 0;
        for (int i = 0; i < n; i++) {
            v[i] = nextInt();
            w[i] = nextInt();
            sumv += v[i];
            sumw += w[i];
            assert (0 <= v[i]) && (v[i] <= MAX_VALUE);
            assert (1 <= w[i]) && (w[i] <= MAX_WEIGHT);
        }
        assert sumv <= MAX_VALUE_SUM;
        assert sumw <= MAX_WEIGHT_SUM;

        double l = 0;
        double r = MAX_VALUE;
        double m = (l + r) / 2;
        s = new double[n];
        while (m != l && m != r && r - l > EPS) {
            for (int i = 0; i < n; i++) {
                s[i] = v[i] - m * w[i];
            }

            double kth = kth(0, n - 1, k - 1);

            int p = 0;
            double sv = 0;
            for (int i = 0; i < n; i++) {
                if (s[i] > kth) {
                    sv += s[i];
                    p++;
                }
            }
            sv += (k - p) * kth;
            if (sv >= 0) {
                l = m;
            } else {
                r = m;
            }

//            System.out.printf("m = %.20f, kth = %.20f, sv = %.20f\n", m, kth, sv);

            m = (l + r) / 2;
        }

        for (int i = 0; i < n; i++) {
            s[i] = v[i] - m * w[i];
        }
        double kth = kth(0, n - 1, k - 1);
        for (int i = 0; i < n; i++) {
            s[i] = v[i] - m * w[i];
        }
        int p = 0;
        int[] a = new int[k];
        for (int i = 0; i < n; i++) {
            if (s[i] > kth) {
                a[p++] = i;
            }
        }
        for (int i = 0; i < n; i++) {
            if (s[i] == kth && p < k) {
                a[p++] = i;
            }
        }
        Arrays.sort(a);

        PrintWriter out = new PrintWriter(new File("k.out"));
        for (int i = 0; i < k; i++) {
            out.print(a[i] + 1);
            if (i < k - 1) {
                out.print(" ");
            }
        }
        out.println();
        out.close();
    }

    StreamTokenizer in;

    public void initInput(String name) {
        try {
            in = new StreamTokenizer(new FileReader(name));
        } catch (FileNotFoundException e) {
        }
    }

    public int nextInt() {
        try {
            in.nextToken();
        } catch (IOException e) {
        }
        return (int) in.nval;
    }

    public static void main(String[] args) throws FileNotFoundException {
        new k_as().run();
    }

}
