uses
	math;

const
	maxn = 100;
	maxs = 500;
	md = 1000;

type
	tlong = object
		l: longint;
		v: array [1..maxs] of longint;

		function get(i: longint): longint;
	end;

	tperm = array [1..maxn] of longint;

procedure init(var r: tlong; x: longint);
begin
    r.l := 1;
    r.v[1] := x;
end;

function tlong.get(i: longint): longint;
begin
	if i > l then
		get := 0
	else
		get := v[i];
end;

function lt(const x, y: tlong): boolean;
var
	i, u: longint;
begin
	u := max(x.l, y.l);

	lt := false;
	for i := u downto 1 do
	begin
		if x.get(i) < y.get(i) then
   		begin
   			lt := true;
   			exit;
   		end;
		if x.get(i) > y.get(i) then
   			exit;
	end;
end;

procedure add(const x, y: tlong; var r: tlong);
var
    i, c, u: longint;
begin
    c := 0;
    u := max(x.l, y.l);
    for i := 1 to u do
    begin
        c := c + x.v[i] + y.v[i];
        r.v[i] := c mod md;
        c := c div md;
    end;
    if c = 0 then
        r.l := u
    else
    begin
        if (u = maxs) then
            runerror(123);
        r.v[u + 1] := c;
        r.l := u + 1;
    end;
end;

procedure sub(const x, y: tlong; var r: tlong);
var
    i, c: longint;
begin
    c := 0;
    for i := 1 to x.l do
    begin
        c := c + x.v[i] - y.v[i];
        r.v[i] := (c + md) mod md;
        c := (c + md) div md - 1;
    end;
    r.l := x.l;
    while (r.l > 1) and (r.v[r.l] = 0) do
    	r.l := r.l - 1;
end;

procedure muls(const x: tlong; y: longint; var r: tlong);
var
    i, c: longint;
begin
    if y = 0 then
    begin
        init(r, 0);
        exit;
    end;

    c := 0;
    for i := 1 to x.l do
    begin
        c := c + x.v[i] * y;
        r.v[i] := c mod md;
        c := c div md;
    end;
    r.l := x.l;
    while c > 0 do
    begin
        inc(r.l);
        if (r.l > maxs) then
            runerror(123);
        r.v[r.l] := c mod md;
        c := c div md;
    end;
end;

procedure divs(const x: tlong; y: longint; var r: tlong);
var
    i, c: longint;
begin
    c := 0;
    for i := x.l downto 1 do
    begin
        c := c * md + x.v[i];
        r.v[i] := c div y;
        c := c mod y;
    end;

    i := x.l;
    while (i > 1) and (r.v[i] = 0) do
        dec(i);
    r.l := i;
end;

procedure mul(const x, y: tlong; var r: tlong);
var
    i, j: longint;
begin
    if x.l + y.l > maxs then
        runerror(123);
    for i := 1 to x.l + y.l do
        r.v[i] := 0;
    for i := 1 to x.l do
        for j := 1 to y.l do
            r.v[i + j - 1] := r.v[i + j - 1] + x.v[i] * y.v[j];
    for i := 1 to x.l + y.l - 1 do
    begin
        r.v[i + 1] := r.v[i + 1] + r.v[i] div md;
        r.v[i] := r.v[i] mod md;
    end;
    i := x.l + y.l;
    while (i > 1) and (r.v[i] = 0) do
        dec(i);
    r.l := i;
end;

procedure print(const r: tlong);
var
    i, j, k: longint;
begin
    write(r.v[r.l]);
    for i := r.l - 1 downto 1 do
    begin
        j := md;
        k := r.v[i];
        while j > 1 do
        begin
            j := j div 10;
            write(k div j);
            k := k mod j;
        end;
    end;
    writeln;
end;

var
	tc: array [0..maxn] of tlong;
	n, i: longint;
	tmp, one: tlong;
    b, p: tperm;
    l, r: tlong;

function getinv(x: tlong; m: longint): tperm;
var
	i, j: longint;
begin
	if m = 1 then
		result[1] := 1;
	if m <= 1 then exit;

  	if lt(x, tc[m - 1]) then
  	begin
  		result := getinv(x, m - 1);
        for i := m downto 2 do
            result[i] := result[i - 1] + 1;
  		result[1] := 1;
  	end else begin
  		sub(x, tc[m - 1], x);

  		j := 2;
  		while not lt(x, tc[m - 2]) do
  		begin
            sub(x, tc[m - 2], x);
  			inc(j);
  		end;

  		result := getinv(x, m - 2);
        for i := m downto 2 do
            result[i] := result[i - 1] + 1;

  		result[1] := j;
  		for i := 2 to m - 1 do
  			if result[i] >= j then
  				inc(result[i]);
  		for i := m downto j + 1 do
  			result[i] := result[i - 1];
  		result[j] := 1;
  	end;
end;

procedure outperm(x: tperm);
var
	i: longint;
begin
	for i := 1 to n do
		if i < n then
			write(x[i], ' ')
		else
			writeln(x[i]);
end;

function lep(const a, b: tperm): boolean;
begin
    lep := true;
    for i := 1 to n do
    begin
        if a[i] < b[i] then
            exit;
        if a[i] > b[i] then
        begin
            lep := false;
            exit;
        end;
    end;
end;

begin
	assign(input, 'in.in');
	reset(input);
	assign(output, 'in.out');
	rewrite(output);

	read(n);
    for i := 1 to n do
        read(b[i]);

	init(tc[0], 1);
	init(tc[1], 1);
	for i := 2 to n do
	begin
		tc[i] := tc[i - 1];
		muls(tc[i - 2], i - 1, tmp);
		add(tc[i], tmp, tc[i]);
	end;

    init(l, 0);
    r := tc[n];
    init(one, 1);
    while lt(l, r) do
    begin
        add(l, r, tmp);
        divs(tmp, 2, tmp);
        p := getinv(tmp, n);
        if lep(p, b) then
        begin
            l := tmp;
            add(l, one, l);
        end else begin
            r := tmp;
        end;
    end;
    if lt(l, tc[n]) then
    begin
        writeln(n);
        outperm(getinv(l, n))
    end else begin
        writeln(0);
    end;

	close(input);
	close(output);
end.
