{$apptype CONSOLE}
{$R-,O+}

uses Math;

const
    inFile = 'palindr.in';
    outFile = 'palindr.out';

    maxN = 600000;
    inf = maxint;

type
    TIntArray = array[0..maxN] of integer;

var
    n : integer;
    alpha : string;
    answer : int64;

    pos, inv, col : array[boolean] of TIntArray;
    count, rel, tmp : TIntArray;

    q, w : TIntArray;

procedure ReadData;
begin
    assign(input, inFile);
    reset(input);
    readln(alpha);
    close(input);
end;

procedure WriteData;
begin
    assign(output, outFile);
    rewrite(output);

    writeln(answer);

    close(input);
end;

function Reverse(s : string) : string;
var
    i : integer;
    tmp : char;

begin
    result := s;
    for i := 1 to length(s) div 2 do begin
        tmp := result[i];
        result[i] := result[length(s) - i + 1];
        result[length(s) - i + 1] := tmp;
    end;
end;


function GetMin(lo, hi : integer) : integer;

    function Go(left, right, i : integer) : integer;
    var
        mid : integer;

    begin
        while (left < lo) or (hi < right) do begin
            mid := (left + right) shr 1;
            if hi <= mid then begin
                i := i shl 1;
                right := mid
            end else if lo >= mid + 1 then begin
                i := (i shl 1) + 1;
                left := mid + 1;
            end else begin
                result := min(Go(left, mid, i shl 1), Go(mid + 1, right, (i shl 1) + 1));
                exit;
            end;
        end;
        result := q[i];
    end;

begin
    result := Go(1, n, 1);
end;

procedure Update(k, value : integer);

    procedure Go(left, right, i : integer);
    var
        mid : integer;

    begin
        if left < right then begin
            mid := (left + right) shr 1;
            if k <= mid then
                Go(left, mid, i shl 1)
            else
                Go(mid + 1, right, (i shl 1) + 1);
            q[i] := min(q[i shl 1], q[(i shl 1) + 1]);
        end else
            q[i] := value;
    end;

begin
    Go(1, n, 1);
    w[k] := value;
end;

procedure InitSteps(
    var pos : TIntArray;
    var inv : TIntArray;
    var col : TIntArray);
var
    count, rel : array[char] of integer;
    i : integer;
    j : char;

begin
    fillchar(count, sizeof(count), 0);
    fillchar(rel, sizeof(rel), 0);
    for i := 1 to n do
        inc(count[alpha[i]]);
    rel[#0] := 1;
    for j := #1 to #255 do
        rel[j] := rel[pred(j)] + count[pred(j)];
    for i := 1 to n do begin
        pos[rel[alpha[i]]] := i;
        inc(rel[alpha[i]]);
    end;
    col[1] := 1;
    for i := 2 to n do
        if alpha[pos[i]] = alpha[pos[i-1]] then
            col[i] := col[i-1]
        else
            col[i] := col[i-1] + 1;
    for i := 1 to n do
        inv[pos[i]] := i;

    for i := 1 to maxN do begin
        q[i] := inf;
        w[i] := inf;
    end;

    for i := 1 to n - 1 do
        if col[i] <> col[i+1] then
            Update(i, 0);
end;

function lcp(const inv : TIntArray; i, j : integer) : integer;
var
    left, right : integer;

begin
    if (i > n) or (j > n) then begin
        if (i <= n) or (j <= n) then
            result := 0
        else
            result := inf;
        exit;
    end;

    left := inv[i];
    right := inv[j];
    if left < right then
        result := GetMin(left, right - 1)
    else if left > right then
        result := GetMin(right, left - 1)
    else
        result := inf;
end;

procedure MakeStep(
    h : integer;
    var pos1 : TIntArray;
    var inv1 : TIntArray;
    var col1 : TIntArray;
    var pos2 : TIntArray;
    var inv2 : TIntArray;
    var col2 : TIntArray);
var
    i, j : integer;

begin
    for i := 1 to n do
        dec(pos1[i], h);
    j := n;
    for i := n downto 1 do
        if pos1[i] > 0 then begin
            pos1[j] := pos1[i];
            dec(j);
        end;
    for i := 1 to h do
        pos1[i] := n - h + i;

    for j := 1 to n do
        tmp[j] := col1[inv1[j]];

//    fillchar(count, sizeof(count), 0);
	fillchar(count[1], sizeof(integer) * n, 0);

    for i := 1 to n do
        inc(count[tmp[pos1[i]]]);

    rel[1] := 1;
    for i := 2 to n do
        rel[i] := rel[i-1] + count[i-1];

    for i := 1 to n do begin
        pos2[rel[tmp[pos1[i]]]] := pos1[i];
        inc(rel[tmp[pos1[i]]]);
    end;

    for i := 1 to n do
        inv2[pos2[i]] := i;

    col2[1] := 1;
    for i := 2 to n do
        if (col1[inv1[pos2[i]]] = col1[inv1[pos2[i-1]]]) and
           (col1[inv1[pos2[i]+h]] = col1[inv1[pos2[i-1] + h]]) then
            col2[i] := col2[i-1]
        else
            col2[i] := col2[i-1] + 1;

    for i := 1 to n - 1 do
        if (w[i] = inf) and (col2[i] <> col2[i+1]) then
            Update(i, h + lcp(inv2, pos2[i] + h, pos2[i+1] + h));
end;

procedure Solve;
var
    h : integer;
    flag : boolean;
    i : integer;

begin
    alpha := alpha + '$' + Reverse(alpha);
    n := length(alpha);

    fillchar(col, sizeof(col), 0);
    fillchar(inv, sizeof(inv), 0);
    fillchar(pos, sizeof(pos), 0);

    flag := false;
    h := 1;
    InitSteps(pos[flag], inv[flag], col[flag]);

    while h < length(alpha) do begin
        MakeStep(
            h,
            pos[flag], inv[flag], col[flag],
            pos[not flag], inv[not flag], col[not flag]);
        flag := not flag;
        h := h * 2;
    end;

    answer := 0;
    for i := 1 to (n - 1) div 2 do begin
        inc(answer, lcp(inv[flag], i, n - i + 1) - 1);
        if i >= 2 then
            inc(answer, lcp(inv[flag], i, n - i + 2));
    end;
end;

begin
    ReadData;
    Solve;
    WriteData;
end.

