{$I-,Q-,R-,S-}
Program ConvexHuller;
Const
  TaskID='convexh';
  InFile=TaskID+'.in';
  OutFile=TaskID+'.out';
  MaxN=2002;
  MaxP=2*MaxN;
  Eps=1e-9;
Type
  Integer=LongInt;
  Real=Extended;
  TLine=Record
    A,B,C:Real;
  End;
  TPoint=Record
    X,Y:Real;
  End;
Const
  Infinity=1e100;
  PlusInfPoint:TPoint=(X:Infinity; Y:Infinity);
  MinusInfPoint:TPoint=(X:-Infinity; Y:-Infinity);
Var
  N:Integer;
  L:Array[1..MaxN]Of TLine;
  NP:Integer;
  P:Array[1..MaxP]Of TPoint;
  NH:Integer;
  H:Array[1..MaxP]Of TPoint;
  Kind:Array[1..MaxP]Of Integer;
  Res:Real;
Procedure LineByPoints(Const P1,P2:TPoint; Var L:TLine);
Begin
  L.A:=P1.Y-P2.Y;
  L.B:=P2.X-P1.X;
  L.C:=-(P1.X*L.A+P1.Y*L.B);
End;
Procedure Load;
Var
  I:Integer;
  P1,P2:TPoint;
Begin
  Assign(Input,InFile);
  ReSet(Input);
  Read(N);
  For I:=1 To N Do Begin
    Read(P1.X,P1.Y,P2.X,P2.Y);
    LineByPoints(P1,P2,L[I]);
  End;
  Close(Input);
End;
Function Sign(A:Real):Integer;
Begin
  If Abs(A)<Eps Then
    Sign:=0
  Else If A<0 Then
    Sign:=-1
  Else
    Sign:=1;
End;
Function Compare(A,B:Real):Integer;
Begin
  Compare:=Sign(A-B);
End;
Function ComparePoints(Const P1,P2:TPoint):Integer;
Begin
  Case Compare(P1.X,P2.X) Of
    -1:ComparePoints:=-1;
    0:ComparePoints:=Compare(P1.Y,P2.Y);
    1:ComparePoints:=1;
  End;
End;
Procedure CrossLineLine(Const L1,L2:TLine; Var P:TPoint);
Var
  Z:Real;
Begin
  Z:=L1.A*L2.B-L1.B*L2.A;
  P.X:=-(L1.C*L2.B-L1.B*L2.C)/Z;
  P.Y:=-(L1.A*L2.C-L1.C*L2.A)/Z;
End;
Function QLess(Const P1:TPoint; K1:Integer; Const P2:TPoint; K2:Integer):Boolean;
Begin
  If K1<K2 Then
    QLess:=True
  Else If K1>K2 Then
    QLess:=False
  Else Case Sign(P1.X*P2.Y-P2.X*P1.Y) Of
    -1:QLess:=False;
    1:QLess:=True;
    0:
      If Compare(Abs(P1.X)+Abs(P1.Y),Abs(P2.X)+Abs(P2.Y))<0 Then
        QLess:=True
      Else
        QLess:=False;
  End;
End;
Procedure QSort(L,R:Integer);
Var
  I,J:Integer;
  X:TPoint;
  Y:TPoint;
  XK,YK:Integer;
Begin
  I:=L;
  J:=R;
  X:=P[(L+R) Div 2];
  XK:=Kind[(L+R) Div 2];
  Repeat
    While QLess(P[I],Kind[I],X,XK) Do Inc(I);
    While QLess(X,XK,P[J],Kind[J]) Do Dec(J);
    If I<=J Then Begin
      Y:=P[I];
      P[I]:=P[J];
      P[J]:=Y;
      YK:=Kind[I];
      Kind[I]:=Kind[J];
      Kind[J]:=YK;
      Inc(I);
      Dec(J);
    End;
  Until I>J;
  If L<J Then QSort(L,J);
  If I<R Then QSort(I,R);
end;
Procedure HullIt;
Var
  CX,CY:Real;
  I:Integer;
  SI:Integer;
Begin
  CX:=0;
  CY:=0;
  For I:=1 To NP Do Begin
    CX:=CX+P[I].X;
    CY:=CY+P[I].Y;
  End;
  CX:=CX/NP;
  CY:=CY/NP;
  For I:=1 To NP Do Begin
    P[I].X:=P[I].X-CX;
    P[I].Y:=P[I].Y-CY;
  End;
  For I:=1 To NP Do Begin
    Case Sign(P[I].X) Of
      -1:Case Sign(P[I].Y) Of
        -1,0:Kind[I]:=3;
        1:Kind[I]:=2;
      End;
      0:Case Sign(P[I].Y) Of
        -1:Kind[I]:=4;
        1:Kind[I]:=2;
        0:Kind[I]:=5;
      End;
      1:Case Sign(P[I].Y) Of
        -1:Kind[I]:=4;
        0,1:Kind[I]:=1;
      End;
    End;
  End;
  QSort(1,NP);
  While (NP>0) And (Kind[NP]=5) Do Dec(NP);
  NH:=0;
  If NP=0 Then Exit;
  SI:=1;
  For I:=2 To NP Do
    If ComparePoints(P[I],P[SI])<0 Then
      SI:=I;
  Inc(NH);
  H[NH]:=P[SI];
  IF NP=1 Then Exit;
  I:=SI;
  Repeat
    I:=I Mod NP+1;
    Inc(NH);
    H[NH]:=P[I];
    While (NH>=3) And (Sign((H[NH].Y-H[NH-1].Y)*(H[NH-1].X-H[NH-2].X)-(H[NH].X-H[NH-1].X)*(H[NH-1].Y-H[NH-2].Y))<=0) Do Begin
      H[NH-1]:=H[NH];
      Dec(NH);
    End;
  Until I=SI;
End;
Function FindHullArea:Real;
Var
  Area:Real;
  I:Integer;
Begin
  If NH<=3 Then Begin
    FindHullArea:=0;
    Exit;
  End;
  Area:=0;
  For I:=1 To NH-1 Do
    Area:=Area+(H[I+1].X-H[I].X)*(H[I+1].Y+H[I].Y);
  FindHullArea:=Abs(Area)/2;
End;
Procedure Solve;
Var
  I,J:Integer;
  MinP,MaxP,PP:TPoint;
Begin
  If N<=2 Then Begin
    Res:=0;
    Exit;
  End;
  NP:=0;
  For I:=1 To N Do Begin
    MinP:=PlusInfPoint;
    MaxP:=MinusInfPoint;
    For J:=1 To N Do If I<>J Then Begin
      CrossLineLine(L[I],L[J],PP);
      If ComparePoints(PP,MinP)<0 Then
        MinP:=PP;
      If ComparePoints(PP,MaxP)>0 Then
        MaxP:=PP;
    End;
    Inc(NP);
    P[NP]:=MinP;
    Inc(NP);
    P[NP]:=MaxP;
  End;
  HullIt;
  Res:=FindHullArea;
End;
Procedure Save;
Begin
  Assign(Output,OutFile);
  ReWrite(Output);
  WriteLn(Res:0:18);
  Close(Output);
End;
Begin
  Load;
  Solve;
  Save;
End.
