{$APPTYPE CONSOLE}
{.$define DEBUG}

{$Q-,R-,O+}

program solution;

uses
	SysUtils;

const
	maxP = 1000;
	maxH = 6;
    maxT = 26;
    maxNFAStates = 51;
    maxDFAStates = 1024*1024;
    hashSize = 100001;

    terms = ['a'..'z'];
    nterms = ['A'..'Z'];

    inFile = 'left.in';
    outFile = 'left.out';

    modulo = 1000000000;

type
	integer = longint;

    TColor = (_white, _gray, _black);

    THuge = array[1..maxH] of integer;

	TProduction = record
		lhs : char;
		rhs : string;
        baseNFAState : integer;
    end;

	TNFAState = record
    	prod : integer;
        pos : integer;
    end;

    TDFAState = set of 0..maxNFAStates;

    THashItem = record
    	state : TDFAState;
        color : TColor;
        next : integer;
        answer : THuge;
    end;

    TTermSet = set of 'a'..'z';
    TNTermSet = set of 'A'..'Z';

var
	n : integer;
	p : array[1..maxP] of TProduction;
	startNT : char;

    nNFAStates : integer;
    nfaStates : array[1..maxNFAStates] of TNFAState;
    baseNTState : integer;
    nt2NFAState : array[char] of integer;
    nfaState2NT : array[1..maxNFAStates] of char;

    hashBucket : array[0..hashSize-1] of integer;
    nDFAStates : integer;
    dfaStates : array[1..maxDFAStates] of THashItem;

    ntLo, ntHi : array[char] of integer;

    ntEpsClosure : array[char] of TNTermSet;
    nullable : array[char] of boolean;
    ntEpsClosureStates : array[char] of TDFAState;
    activeNT : TNTermSet;

    answer : THuge;

procedure InitHuge(var h : THuge; value : integer);
begin
    fillchar(h, sizeof(h), 0);
    h[1] := value;
end;

procedure AddHuge(var a : THuge; const b : THuge);
var
    i : integer;
    value, carry : integer;

begin
    carry := 0;
    for i := 1 to maxH do begin
        value := a[i] + b[i] + carry;
        if value >= modulo then begin
            a[i] := value - modulo;
            carry := 1;
        end else begin
            a[i] := value;
            carry := 0;
        end;
    end;

    if carry <> 0 then
        runerror(123);
end;

procedure PrintHuge(const h : THuge);
var
    i, j, k : integer;
    s : string;

begin
    i := maxH;
    while (i > 0) and (h[i] = 0) do
        dec(i);
    if i = 0 then begin
        write(0);
        exit;
    end;
    write(h[i]);
    for j := i - 1 downto 1 do begin
        str(h[j], s);
        for k := 1 to 9 - length(s) do
            write(0);
        write(h[j]);
    end;
end;

function strtok(var s : string) : string;
begin
	result := '';
    while (s[1] = ' ') do
    	delete(s, 1, 1);
    while (length(s) > 0) and (s[1] <> ' ') do begin
    	result := result + s[1];
        delete(s, 1, 1);
    end;
end;

function compress(s : string) : string;
var
	i : integer;

begin
    result := '';
    for i := 1 to length(s) do
    	if s[i] <> ' ' then
        	result := result + s[i];
end;

procedure ReadData;
var
	s : string;
    i, j : integer;
    sum : integer;
    curNTerms : TNTermSet;
    nt : char;
    
begin
	assign(input, inFile);
    reset(input);

    readln(s);
    n := strtoint(strtok(s));
    startNT := strtok(s)[1];

    curNTerms := [startNT];
    for i := 1 to n do begin
    	readln(s);
        j := pos('->', s);
        p[i].lhs := compress(copy(s, 1, j - 1))[1];
        p[i].rhs := compress(copy(s, j + 2, length(s) - j - 1));
        include(curNTerms, p[i].lhs);
        if (length(p[i].rhs) > 0) and (p[i].rhs[1] in curNTerms) then
            include(curNTerms, p[i].rhs[1]);
    end;

    sum := 0;
    for i := 1 to n do
        inc(sum, length(p[i].rhs));
    sum := sum - 2 * n;
    for nt := 'A' to 'Z' do
        if nt in curNTerms then
            inc(sum);
    if sum > 50 then
    begin
    	writeln(sum);
        runerror(123);
    end;

    close(input);
end;

procedure WriteData;
begin
	assign(output, outFile);
    rewrite(output);
    PrintHuge(answer);
	writeln;
{$ifdef DEBUG}
	writeln('NFA states = ', nNFAStates, ', DFAStates = ', nDFAStates);
{$endif}
    close(output);
end;

procedure InitNFAStates;
var
	i, j : integer;

begin
    activeNT := [];
    for i := 1 to n do
        include(activeNT, p[i].lhs);

	nNFAStates := 0;
    for i := 1 to n do begin
    	p[i].baseNFAState := nNFAStates + 1;
    	for j := length(p[i].rhs) - 1 downto 1 do begin
        	if p[i].rhs[j] in nterms then
            	break;
        	inc(nNFAStates);
            nfaStates[nNFAStates].prod := i;
            nfaStates[nNFAStates].pos := j;
        end;
	end;

    fillchar(nt2NFAState, sizeof(nt2NFAState), 0);
    fillchar(nfaState2NT, sizeof(nfaState2NT), 0);
    baseNTState := nNFAStates + 1;
    for i := 1 to n do
    	if nt2NFAState[p[i].lhs] = 0 then begin
        	inc(nNFAStates);
            nt2NFAState[p[i].lhs] := nNFAStates;
            nfaState2NT[nNFAStates] := p[i].lhs;
        end;
end;

procedure InitEpsClosureStates;
var
	nt1, nt2 : char;

begin
    for nt1 := 'A' to 'Z' do
        if nt1 in activeNT then begin
        	ntEpsClosureStates[nt1] := [];
            if nullable[nt1] then
            	include(ntEpsClosureStates[nt1], 0);
            for nt2 := 'A' to 'Z' do
            	if (nt2 in activeNT) and (nt2 in ntEpsClosure[nt1]) then
                	include(ntEpsClosureStates[nt1], nt2NFAState[nt2]);
        end;
end;

function GetHash(const state : TDFAState) : integer;
var
	i, tmp : integer;
begin
	result := 0;
    tmp := 1;
    for i := 1 to nNFAStates do begin
    	if i in state then
        	result := (result + tmp) mod hashSize;
        tmp := (tmp * 1001) mod hashSize;
    end;
end;

procedure InitHashtable;
begin
	fillchar(hashBucket, sizeof(hashBucket), 0);
    nDFAStates := 0;
end;

function LookupHashtable(state : TDFAState) : integer;
var
	i : integer;
	hash : integer;

begin
	hash := GetHash(state);
	i := hashBucket[hash];
    while i <> 0 do begin
		if dfaStates[i].state = state then begin
         	result := i;
			exit;
		end;
		i := dfaStates[i].next;
    end;

	inc(nDFAStates);
    if nDFAStates mod 1000 = 0 then
        writeln(nDFAStates);
	dfaStates[nDFAStates].state := state;
	dfaStates[nDFAStates].next := hashBucket[hash];
	dfaStates[nDFAStates].color := _white;
	InitHuge(dfaStates[nDFAStates].answer, -1);
    hashBucket[hash] := nDFAStates;
    result := nDFAStates;
end;

function GetNFAState(prod, pos : integer) : integer;
begin
	result := p[prod].baseNFAState + length(p[prod].rhs) - pos - 1;
end;

function GetActiveTerms(state : integer) : TTermSet; overload;
var
	t : char;
    i : integer;

begin
	result := [];
	if state < baseNTState then begin
		include(result, p[nfaStates[state].prod].rhs[nfaStates[state].pos]);
    end else begin
		for i := ntLo[nfaState2NT[state]] to ntHi[nfaState2NT[state]] do begin
        	t := p[i].rhs[length(p[i].rhs)];
        	if t in terms then
            	include(result, t);
        end;
    end;
end;

function GetActiveTerms(state : TDFAState) : TTermSet; overload;
var
	i : integer;

begin
	result := [];
    for i := 1 to nNFAStates do
    	if i in state then
        	result := result + GetActiveTerms(i);
end;

function EpsClosure(state : TDFAState) : TDFAState;
var
	i : integer;

begin
	result := state;
    for i := baseNTState to nNFAStates do
    	 if i in state then
         	result := result + ntEpsClosureStates[nfaState2nt[i]];
end;

function NFAGoto(state : TDFAState; t : char) : TDFAState;
var
	i, j : integer;
    prod : integer;
    pos : integer;
    nt : char;

begin
	result := [];
    for i := 1 to baseNTState - 1 do
    	if i in state then begin
        	prod := nfaStates[i].prod;
        	pos := nfaStates[i].pos;
        	if p[prod].rhs[pos] = t then begin
				if pos = 1 then begin
                	include(result, 0);
                end else begin
                	if p[prod].rhs[pos - 1] in terms then
                    	include(result, GetNFAState(prod, pos - 1))
                    else
                    	include(result, nt2NFAState[p[prod].rhs[pos - 1]]);
                end;
	        end;
        end;

    for i := baseNTState to nNFAStates do
    	if i in state then begin
        	nt := nfaState2nt[i];
        	for j := ntLo[nt] to ntHi[nt] do
            	if t = p[j].rhs[length(p[j].rhs)] then begin
	            	if length(p[j].rhs) = 1 then begin
                    	include(result, 0);
        	        end else
    	            if (length(p[j].rhs) = 2) and (p[j].rhs[1] in nterms) then begin
						include(result, nt2nfaState[p[j].rhs[1]]);
		       	    end else begin
						include(result, GetNFAState(j, length(p[j].rhs) - 1));
                	end;
                end;
        end;
end;

procedure SortProductions;
var
	i, j : integer;
	tmp : TProduction;

begin
	for i := 1 to n do
    	for j := i + 1 to n do
        	if p[i].lhs > p[j].lhs then begin
            	tmp := p[i];
                p[i] := p[j];
                p[j] := tmp;
            end;

end;

procedure InitNTEpsClosures;
var
    nt : char;

	procedure DFS(baseNT, nt : char);
    var
    	i : integer;

    begin
    	if nt in ntEpsClosure[baseNT] then
        	exit;
        include(ntEpsClosure[baseNT], nt);
    	for i := ntLo[nt] to ntHi[nt] do begin
        	if length(p[i].rhs) = 0 then
            	nullable[baseNT] := true
            else if (length(p[i].rhs) = 1) and (p[i].rhs[1] in nterms) then
            	DFS(baseNT, p[i].rhs[1]);
        end;
    end;

begin
	for nt := 'A' to 'Z' do begin
    	ntEpsClosure[nt] := [];
        nullable[nt] := false;
        DFS(nt, nt);
    end;
end;

procedure InitLoHi;
var
    nt : char;
    i : integer;

begin
    for nt := #0 to #255 do begin
    	ntLo[nt] := maxint;
        ntHi[nt] := -maxint;
    end;

    for i := 1 to n do begin
    	if ntLo[p[i].lhs] > i then
        	ntLo[p[i].lhs] := i;
        if ntHi[p[i].lhs] < i then
        	nthi[p[i].lhs] := i;
    end;
end;

procedure RemoveDeadProductions;
var
	used : array[char] of boolean;
    again : boolean;
    i, j : integer;

begin
	fillchar(used, sizeof(used), false);
    repeat
    	again := false;
		for i := 1 to n do
        	if ((length(p[i].rhs) = 0) or
               (length(p[i].rhs) > 0) and (p[i].rhs[1] in terms) or
               (length(p[i].rhs) > 0) and used[p[i].rhs[1]]) and
               not used[p[i].lhs] then begin
            	used[p[i].lhs] := true;
                again := true;
            end;
    until not again;

    j := 0;
    for i := 1 to n do
    	if used[p[i].lhs] and
           not ((length(p[i].rhs) > 0) and (p[i].rhs[1] in nterms) and not used[p[i].rhs[1]]) then begin
        	inc(j);
            p[j] := p[i];
        end;
    n := j;
end;

procedure RemoveTrivialProductions;
var
	i, j : integer;

begin
	j := 0;
    for i := 1 to n do
    	if (length(p[i].rhs) >= 1) and (p[i].rhs[length(p[i].rhs)] in terms) then begin
        	inc(j);
            p[j] := p[i];
        end;
    n := j;
end;

procedure PrintNFAState(state : integer);
var
	i : integer;

begin
	if state = 0 then
    	write('#')
    else if state < baseNTState then begin
    	write(p[nfaStates[state].prod].lhs, '->');
    	for i := 1 to nfaStates[state].pos do
        	write(p[nfaStates[state].prod].rhs[i]);
        write('.');
        for i := nfaStates[state].pos + 1 to length(p[nfaStates[state].prod].rhs) do
        	write(p[nfaStates[state].prod].rhs[i]);
    end else
    	write(nfaState2nt[state]);
end;

procedure PrintDFAState(state : TDFAState);
var
	i : integer;

begin
	write('{ ');
    for i := 0 to nNFAStates do
    	if i in state then begin
        	PrintNFAState(i);
            write(' ');
        end;
    write('}');
end;

procedure Infinity;
begin
	assign(output, outFile);
    rewrite(output);
    writeln('infinity');
{$ifdef DEBUG}
	writeln('NFA states = ', nNFAStates, ', DFAStates = ', nDFAStates);
{$endif}
    close(output);
    halt;
end;

{$ifdef DEBUG}
procedure PrintTermSet(ts : TTermSet);
var
	t : char;

begin
	write('{ ');
    for t := #0 to #255 do
    	if t in ts then
        	write(t, ' ');
    write('}');
end;
{$endif}

function DFS(curStateID : integer) : THuge;
var
	curState : TDFAState;
    newStateID : integer;
	newState : TDFAState;
    actTerms : TTermSet;
    t : char;

begin
	curState := dfaStates[curStateID].state;
    dfaStates[curStateID].color := _gray;

	if 0 in curState then
    	InitHuge(result, 1)
    else
    	InitHuge(result, 0);

{$ifdef DEBUG}
	PrintDFAState(curState);
{$endif}

	actTerms := GetActiveTerms(curState);

{$ifdef DEBUG}
	write(' has transitions on ');
    PrintTermSet(actTerms);
    writeln;
{$endif}

	for t := 'a' to 'z' do
       	if t in actTerms then begin
           	newState := EpsClosure(NFAGoto(curState, t));
			newStateID := LookupHashtable(newState);

{$ifdef DEBUG}
			write('On ', t, ' goto ');
		    PrintDFAState(newState);
		    writeln;
{$endif}
            if dfaStates[newStateID].color = _gray then
            	Infinity
            else if dfaStates[newStateID].color = _black then
            	AddHuge(result, dfaStates[newStateID].answer)
            else
				AddHuge(result, DFS(newStateID));
		end;

    dfaStates[curStateID].color := _black;
    dfaStates[curStateID].answer := result;
end;

{$ifdef DEBUG}
procedure PrintProductions;
var
	i : integer;

begin
	for i := 1 to n do
    	writeln(p[i].lhs, '->', p[i].rhs);
end;
{$endif}

procedure Solve;
begin
{$ifdef DEBUG}
	writeln('Initial grammar:');
    PrintProductions;
{$endif}

    RemoveDeadProductions;
	SortProductions;
{$ifdef DEBUG}
	writeln('After dead nonterminals removed:');
    PrintProductions;
{$endif}

    InitLoHi;
    InitNTEpsClosures;
    InitLoHi;
    RemoveTrivialProductions;
	InitNFAStates;
    InitEpsClosureStates;

{$ifdef DEBUG}
	writeln('After trivial productions removed:');
    PrintProductions;
{$endif}

    InitLoHi;
    InitHashtable;
    if not (startNT in activeNT) then begin
        if nullable[startNT] then
            InitHuge(answer, 1)
        else
            InitHuge(answer, 0);
    end else
        answer := DFS(LookupHashtable(ntEpsClosureStates[startNT]));
        
end;

begin
  ReadData;
  Solve;
  WriteData;
end.
