{$A+,B-,C+,D+,E-,F-,G+,H+,I+,J-,K-,L+,M-,N+,O-,P+,Q-,R+,S+,T-,U-,V+,W-,X+,Y+,Z1}
{$apptype console}

uses
  testlib, sysutils;

const
  nmax = 300;

type
  int = longint;

  TSet = class
    set_ : array [1..nmax] of boolean;
    constructor Create; 
  end;

  TGraph = class
    adj : array [1..nmax, 1..nmax] of boolean;
    clr : array [1..nmax, 1..nmax] of boolean;
    n : int;
    usable : array [1..nmax] of boolean;
    constructor Create(n : int);
    procedure findClosure;
    function findBase : TSet;
    function findAntiBase : TSet;
    procedure Trans;
    function mergePair(ind1, ind2 : int; rebuildClr : Boolean) : boolean;
  end;

  constructor TSet.Create;
  begin
    fillchar(set_, SizeOf(set_), 0);
  end;

  constructor TGraph.Create(n : int);
    var
      i : int;
  begin
    for i := 1 to n do usable[i] := True;
    fillchar(adj, SizeOf(adj), 0);
    fillchar(clr, SizeOf(clr), 0);
    fillchar(usable, SizeOf(usable), 1);
    Self.n := n;
  end;

  procedure TGraph.findClosure; (* O(n^3) *)
    var
      i, j, k : int;
  begin
    move(adj, clr, SizeOf(adj));
    for i := 1 to n do clr[i, i] := true;
    for k := 1 to n do
      for i := 1 to n do
        for j := 1 to n do
          clr[i, j] := clr[i, j] or (clr[i, k] and clr[k, j]);
  end;

  procedure TGraph.Trans; (* O(n^2) *)
    var
      i, j : int;
      t : boolean;
  begin
    for i := 1 to n - 1 do
      for j := i + 1 to n do begin
        t := adj[i, j];
        adj[i, j] := adj[j, i];
        adj[j, i] := t;
      end;
  end;

  function TGraph.findBase : TSet; (* O(n^2) *)

    var
      leaveTime : array [1..nmax] of int;
      used : array [1..nmax] of int;
      timer : int;
      cntTree : int;

    procedure rec(ind : int);
      var
        i : int;
    begin
      inc(timer);
      if used[ind] <> 0 then exit;
      used[ind] := cntTree;
      for i := 1 to n do
        if adj[ind, i] then rec(i);
      leaveTime[ind] := timer;
      inc(timer);
    end;

    var
      i, j : int;
      p : array [1..nmax] of int;
      inDegree : array [1..nmax] of int;
      t : int;
  begin
    timer := 0;
    fillchar(used, SizeOf(used), 0);
    cntTree := 0;
    for i := 1 to n do
      if used[i] = 0 then begin
        inc(cntTree);
        rec(i);
      end;
    for i := 1 to n do p[i] := i;
    for i := 1 to n - 1 do
      for j := i + 1 to n do
        if leaveTime[p[i]] < leaveTime[p[j]] then begin
          t := p[i];
          p[i] := p[j];
          p[j] := t;
        end;
    Trans;
    fillchar(used, SizeOf(used), 0);
    cntTree := 0;
    for i := 1 to n do
      if used[p[i]] = 0 then begin
        inc(cntTree);
        rec(p[i]);
      end;
    fillchar(inDegree, SizeOf(inDegree), 0);
    Trans;
    for i := 1 to n do
      for j := 1 to n do
        if adj[i, j] then
          if used[i] <> used[j] then
            inc(inDegree[used[j]]);
    Result := TSet.Create;      
    for i := 1 to cntTree do
      if inDegree[i] = 0 then begin
        for j := 1 to n do
          if used[j] = i then begin
            Result.set_[j] := True;
            break;
          end;
      end;
  end;

  function TGraph.findAntiBase : TSet;
  begin
    Trans;
    Result := findBase;
    Trans;
  end;

  function TGraph.mergePair(ind1, ind2 : int; rebuildClr : Boolean) : boolean;
    var
      i, j : int;
      t : int;
  begin
    Result := False;
    if (ind1 < 1) or (ind1 > n) then exit;
    if (ind2 < 1) or (ind2 > n) then exit;
    if (not usable[ind1]) or (not usable[ind2]) then exit;
    if (ind1 = ind2) then begin
      Result := True;
      Exit;
    end;
    if ind1 > ind2 then begin
      t := ind1;
      ind1 := ind2;
      ind2 := t;
    end;
    for i := 1 to n do
      adj[ind1, i] := adj[ind1, i] or adj[ind2, i];
    for i := 1 to n do
      adj[i, ind1] := adj[i, ind1] or adj[i, ind2];
    for i := 1 to n do begin
      adj[i, ind2] := False;
      adj[ind2, i] := False;
    end;
    usable[ind2] := False;
    if rebuildClr then begin
      for i := 1 to n do
        for j := 1 to n do begin
          if usable[i] and usable[j] and (not clr[i, j]) and ((clr[i, ind1] and clr[ind2, j]) or (clr[i, ind2] and clr[ind1, j])) then
            clr[i, j] := True;
        end;
      for i := 1 to n do
        for j := 1 to n do
          if (not usable[i]) or (not usable[j]) then clr[i, j] := False;
    end;
    Result := True;
  end;

  var
    ans_ : int;
    graph : TGraph;
    n, m : int;
    a, b : int;
    base : TSet;
    antibase : TSet;

  function graphPartlyStrong : Boolean;
    var
      i, j : int;
      cnt : int;
  begin
    Result := False;

    for i := 1 to n do begin
      cnt := 0;
      if base.set_[i] then
        for j := 1 to n do
          if (antibase.set_[j]) and (graph.clr[i, j] and graph.clr[j, i]) then inc(cnt);
      if (cnt <> 1) and (base.set_[i]) then begin
        Exit;
      end;
    end;

    for i := 1 to n do begin
      cnt := 0;
      if antibase.set_[i] then
        for j := 1 to n do
          if (base.set_[j]) and (graph.clr[j, i] and graph.clr[i, j]) then inc(cnt);
      if (cnt <> 1) and (antibase.set_[i]) then begin
        Exit;
      end;
    end;

    Result := True;
  end;

  var
    i, j : int;
    baseAmount : int;
    antibaseAmount : int;
    uans : int;

begin
    n := inf.readlongint;
    graph := TGraph.Create(n);
    m := inf.readlongint;
    for i := 1 to m do begin
      a := inf.readlongint;
      b := inf.readlongint;
      graph.adj[a, b] := True;
    end;

    graph.findClosure;

    base := graph.findBase;
    antibase := graph.findAntiBase;

    if graphPartlyStrong then begin
      ans_ := 0;
      for i := 1 to n do
        inc(ans_, ord(base.set_[i]));
      dec(ans_);  
    end else begin
      baseAmount := 0;
      antibaseAmount := 0;
      for i := 1 to n do begin
        inc(baseAmount, ord(base.set_[i]));
        inc(antibaseAmount, ord(antibase.set_[i]));
      end;
      if baseAmount > antibaseAmount then
        ans_ := baseAmount
      else
        ans_ := antibaseAmount;
    end;

    uans := ouf.readlongint;
    for i := 1 to uans do begin
      a := ouf.ReadLongint;
      b := ouf.ReadLongint;
      if not graph.mergePair(a, b, True) then quit(_wa, 'Trying to merge disabled vertex with smth...');
    end;

    for i := 1 to n do
      for j := 1 to n do
        if (graph.usable[i]) and (graph.usable[j]) and (not graph.clr[i, j]) then
          quit(_wa, 'Vertex ' + IntToStr(j) + ' are not reachable from ' + IntToStr(i) + '...');

  if uans < ans_ then
    quit(_fail, 'Participant''s solution is better: ' + IntToStr(uans) + ' < ' + IntToStr(ans_));

  if uans > ans_ then
    quit(_wa, 'Too many merges: ' + IntToStr(uans) + ' > ' + IntToStr(ans_));

  quit(_ok, 'Correct answer. Number of merges = ' + IntToStr(uans));
end.
