#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>
#include "game.h"

#define maxN    50
#define maxP    1500000

struct TPos
{
        int len;
        int a[maxN+1];
};

static int  n;

static int  solved[maxP+1];
static int  wins[maxP+1];
static int  q1[maxN+1][maxN+1], q2[maxN+1][maxN+1];
static int  w1[maxN+1], w2[maxN+1];

static int curPos[maxN+1];

static struct TPos MakePos_res;
static struct TPos *MakePos(int n)
{
    MakePos_res.len = 1;
    MakePos_res.a[1] = n;
    return (&MakePos_res);
}

static void SortPos(struct TPos *p)
{
    int i, j;
    int tmp;

    for (i = 1; i <= p->len; i++)
        for (j = i + 1; j <= p->len; j++)
            if (p->a[i] > p->a[j])
            {
                tmp = p->a[i];
                p->a[i] = p->a[j];
                p->a[j] = tmp;
            }
}


static struct TPos *MakeMove(const struct TPos *p, struct TPos *np, int k, int a)
{
    int i;

    np->len = 0;
    for (i = 1; i <= p->len; i++)
    {
        if ((i != k) && (p->a[i] > 1))
        {
            np->len++;
            np->a[np->len] = p->a[i];
        }
        else if ((i == k) && (a > 1))
        {
            np->len++;
            np->a[np->len] = a;
        }
    }

    if (p->a[k] - a - 2 > 1)
    {
        np->len++;
        np->a[np->len] = p->a[k] - a - 2;
    }

    SortPos(np);
    return np;
}

static int EncodePos(const struct TPos *p)
{
    int code, sum;
    int i;

    sum = 0;
    for (i = 1; i <= p->len; i++)
        sum += p->a[i]; 

    code = w2[sum];
    for (i = p->len; i >= 1; i--)
    {
        code += q2[sum][p->a[i]];
        sum  -= p->a[i];
    }

    return code;
}

static struct TPos PosByFullPos_res;
static struct TPos *PosByFullPos(const int *fp)
{
    int i;
    int count[maxN+1];

    memset(count, 0, sizeof(count));

    for (i = 1; i <= n; i++)
        if (fp[i] != 0)
            count[fp[i]]++;

    PosByFullPos_res.len = 0;
    for (i = 1; i <= n; i++)
        if (count[i] > 1)
        {
            PosByFullPos_res.len++;
            PosByFullPos_res.a[PosByFullPos_res.len] = count[i];
        }

    SortPos(&PosByFullPos_res);

    return &PosByFullPos_res;
}

static int Rec(const struct TPos *p)
{
    int code;
    int i;
    int a;
    struct TPos np;

    if (p->len == 0)
        return 1;

    code = EncodePos(p);
    if (solved[code])
        return wins[code];

    wins[code] = 0;

    for (i = 1; i <= p->len; i++)
        for (a = 0; a <= p->a[i] - 2; a++)
            if (Rec(MakeMove(p, &np, i, a)) == 0)
                wins[code]++;

    solved[code] = 1;
    return wins[code];
}

static void Solve()
{
    int i, j, k;

    memset(q1, 0, sizeof(q1));
    memset(q2, 0, sizeof(q2));

    for (i = 1; i <= maxN; i++)
    {
        q1[i][i] = 1;
        for (j = 1; j <= i - 1; j++)
            for (k = 1; k <= j; k++)
                q1[i][j] += q1[i - j][k];
    }

    for (i = 1; i <= maxN; i++)
        for (j = 2; j <= maxN; j++)
            q2[i][j] = q1[i][j-1] + q2[i][j-1];

    memset(w1, 0, sizeof(w1));
    memset(w2, 0, sizeof(w2));
    for (i = 1; i <= maxN; i++)
        for (j = 1; j <= maxN; j++)
            w1[i] += q1[i][j];

    for (i = 2; i <= maxN; i++)
        w2[i] = w2[i-1] + w1[i-1];

    memset(solved, 0, sizeof(solved));

/*   for (i = 2; i <= maxN; i++)
        Rec(MakePos(i));*/
}

static void RecordMove(const int *fp, int *nfp, int u, int v)
{
    int i;
    int tmp;
    int maxCol;

    maxCol = 0;
    for (i = 1; i <= n; i++)
        if (maxCol < fp[i])
            maxCol = fp[i];

    if (u > v)
    {
        tmp = u;
        u = v;
        v = tmp;
    }

    if (fp != nfp)
        memcpy(nfp, fp, sizeof(int)*(maxN+1));
    for (i = u + 1; i <= v - 1; i++)
        if (nfp[i] == nfp[u])
            nfp[i] = maxCol + 1;

    nfp[u] = 0;
    nfp[v] = 0;
}

void doMove()
{
    int i, j, u, v;
    int bestI, bestJ, curWins, best;
    int fp[maxN+1];

    bestI = 0;
    bestJ = 0;
    best = INT_MAX;

    for (i = 1; i <= n; i++)
        for (j = i + 1; j <= n; j++)
            if ((curPos[i] == curPos[j]) && (curPos[i] != 0))
            {
                RecordMove(curPos, fp, i, j);
                curWins = Rec(PosByFullPos(fp));
                if (curWins < best)
                {
                    bestI = i;
                    bestJ = j;
                    best = curWins;
                }
            }

    if (bestI == 0)
    {
        printf("Can't find move\n");
        exit(0);
    }

    RecordMove(curPos, curPos, bestI, bestJ);
    Move(bestI, bestJ, &u, &v);
    RecordMove(curPos, curPos, u, v);
}

int main()
{
    int i;
    n = Init();
    Solve();
    for (i = 1; i <= n; i++)
        curPos[i] = 1;

    while (1)
        doMove();

    return 0;
}
