program Convex_Hull;
{$N+}
const
  MAXN = 2000; {2000}
  MAXD = MAXN*MAXN div 2;
  EPS = 1e-10;

type
  point = record
    x, y : extended;
  end;

var
  n, m, hs : longint;
  la, lb : array [1..MAXN] of point;
  h, st : array [1..MAXD] of longint;
  s : extended;
  o : point;

procedure Load(infile, outfile : string);
var
  i : longint;
begin
  assign(input,infile);
  reset(input);
  assign(output,outfile);
  rewrite(output);
  read(n);
  m := n*(n-1) div 2;
  for i:=1 to n do
    read(la[i].x,la[i].y,lb[i].x,lb[i].y);
end;

procedure int(a : longint; var b : point);
var
  t1, t2 : longint;
  a1, b1, c1, a2, b2, c2, det : extended;
begin
  t1 := trunc((2*n+1-sqrt(sqr(2*n+1)-4*(2*n+2*a-2)))/2);
  t2 := a - (-sqr(t1)+(2*n+1)*t1-2*n) div 2 + t1;
  a1 := la[t1].y-lb[t1].y;
  a2 := la[t2].y-lb[t2].y;
  b1 := lb[t1].x-la[t1].x;
  b2 := lb[t2].x-la[t2].x;
  c1 := -la[t1].x*lb[t1].y+lb[t1].x*la[t1].y;
  c2 := -la[t2].x*lb[t2].y+lb[t2].x*la[t2].y;
  det := a1*b2-a2*b1;
  b.x := (c1*b2-c2*b1)/det;
  b.y := (a1*c2-c1*a2)/det;
end;

procedure swap(a, b : longint);
var
  t : longint;
begin
  t := h[a];
  h[a] := h[b];
  h[b] := t;
end;

function better(a, b : longint) : boolean;
var
  pa, pb : point;
  f : extended;
begin
  int(a,pa);
  int(b,pb);
  pa.x := pa.x - o.x;
  pa.y := pa.y - o.y;
  pb.x := pb.x - o.x;
  pb.y := pb.y - o.y;
  f := pa.x*pb.y-pa.y*pb.x;
  better := (f<-eps) or ((abs(f)<eps)
    and ((pa.x>pb.x) or (pa.y>pb.y)));
end;

procedure heapify(a : longint);
var
  l : longint;
begin
  l := a;
  if (2*a<=hs) and not better(h[l],h[2*a]) then
    l := 2*a;
  if (2*a+1<=hs) and not better(h[l],h[2*a+1]) then
    l := 2*a+1;
  if l<>a then
  begin
    swap(l,a);
    heapify(l);
  end;
end;

procedure Add(a, b : longint);
var
  p1, p2 : point;
begin
  int(a,p1);
  int(b,p2);
  s := s + (p1.x-p2.x)*(p1.y+p2.y);
end;

procedure Solve;
var
  i, b : longint;
  f, f1, f2 : point;
  sts : longint;
begin
  b := 1;
  int(1,f);
  for i:=2 to m do
  begin
    int(i,f1);
    if (f1.y<f.y) or ((abs(f1.y-f.y)<eps) and (f1.x<f.x)) then
    begin
      b := i;
      f := f1;
    end;
  end;
  o := f;
  hs := m-1;
  for i:=1 to m do
    if i<b then
      h[i] := i
    else
      h[i-1] := i;

  for i:=hs downto 1 do
    heapify(i);
  while hs>1 do
  begin
    swap(1,hs);
    dec(hs);
    heapify(1);
  end;

  sts := 0;
  for i:=1 to m-1 do
  begin
    inc(sts);
    st[sts] := h[i];
    if sts>0 then
      int(st[sts],f1);
    if sts>1 then
      int(st[sts-1],f2);
    while sts>2 do
    begin
      f := f1;
      f1 := f2;
      int(st[sts-2],f2);
      if (f.x-f1.x)*(f1.y-f2.y)<(f.y-f1.y)*(f1.x-f2.x) then
        break;
      st[sts-1] := st[sts];
      dec(sts);
    end;
  end;
  s := 0;
  for i:=1 to sts-1 do
    add(st[i],st[i+1]);
  add(b,st[1]);
  add(st[sts],b);
end;

procedure Save;
begin
  writeln(abs(s)/2:0:2);
  close(input);
  close(output);
end;

var
  yy : point;

begin
  Load('convexh.in','convexh.out');
  Solve;
  Save;
end.
