#include <stdio.h>

FILE*fi,*fo;

#define EPS ((long double)1e-9)

struct TPoint {
  int x,y;
};
struct TEdge {
  int b;
  TEdge*z;
};
class TPlane {
  private:
    int resolve(TPoint*);
    void sort(void);
    void sortsift(int,int);
  public:
    int m,k,n,c;
    TPoint*pa,*pb,*p,*pz;
    int*a,*b;
    long double*s;
    TPlane(void);
    ~TPlane();
    void get(FILE*);
    void put(FILE*);
    void tranzlate(void);
    void spite(int*,int);
};
class TGraph {
  private:
    int l;
    int*f,*q,*d,*r,*s,*t;
    void seek(TPlane*,int);
  public:
    int n,m,k;
    TEdge*e,**a;
    TGraph(void);
    ~TGraph();
    void get(TPlane*);
    void put(TPlane*);
};

TPlane*p;
TGraph*g;

int main(void) {
  p=new TPlane;
  fi=fopen("input.txt","rt");
  p->get(fi);
  fclose(fi);
  g=new TGraph;
  g->get(p);
  g->put(p);
  fo=fopen("output.txt","wt");
  p->put(fo);
  fclose(fo);
  delete g;
  delete p;
  return(0);
}

#define TPointLWR(a,b) \
  ( (a.x<b.x) || ((a.x==b.x)&&(a.y<b.y)) )


void TPlane::spite(int*t,int l) {
  int i,u,v;
  s[c]=0;
  for (i=0; i<l-1; i++) {
    u=t[i]; v=t[i+1];
    s[c]+=( ((long double)p[u].y) + ((long double)p[v].y) )
         *( ((long double)p[u].x) - ((long double)p[v].x) );
  }
  s[c]/=2;
  if (s[c]<-EPS) s[c]=-s[c];
  if (s[c]<EPS) s[c]=0;
  c++;
}
void TGraph::seek(TPlane*p,int u) {
  int i,j,v,w,x,y,h; TEdge*z;
  for (i=0; i<n; i++) { s[i]=0; r[i]=-1; d[i]=-1; }
  q[0]=u; d[u]=0; s[u]=1; l=1;
  for (i=0; i<l; i++) if (s[q[i]]>=0) {
    v=q[i];
    for (z=a[v]; z; z=z->z) if (f[z->b]) {
      w=z->b;
      if (!s[w]) { q[l++]=w; d[w]=d[v]+1; s[w]=1; r[w]=v; }
      else if (r[v]!=w)
      if ( ((s[w]>0)&&(d[w]<=d[v])) || ((s[w]<0)&&(d[w]==d[v])) ) {
        y=2; h=0;
        for (x=v,j=n-1; x>=0; x=r[x],j--) {
          if ((s[x]<0)&&(d[x]<d[v])) break;
          t[j]=x;
          if (x!=u) s[x]=-1; else y--;
        } h=j+1;
        for (x=w,j=n; x>=0; x=r[x],j++) {
          if ((s[x]<0)&&(d[x]<d[w])) break;
          t[j]=x;
          if (x!=u) s[x]=-1; else y--;
        }
        if (y<=0) p->spite(&t[h],j-h);
      }
    }
  }
}

TPlane::TPlane(void) {
  pa=pb=p=pz=0;
  a=b=0;
  s=0;
}
TPlane::~TPlane() {
  if (pa) delete[]pa; if (pb) delete[]pb;
  if (p) delete[]p; if (pz) delete[]pz;
  if (a) delete[]a; if (b) delete[]b;
  if (s) delete[]s;
}
void TPlane::get(FILE*f) {
  if (pa) delete[]pa; if (pb) delete[]pb;
  if (p) delete[]p; if (pz) delete[]pz;
  if (a) delete[]a; if (b) delete[]b;
  if (s) delete[]s;
  int i;
  fscanf(f,"%d",&m);
  k=m<<1;
  pa=new TPoint[m]; pb=new TPoint[m];
  p=new TPoint[k]; pz=new TPoint[k];
  a=new int[m]; b=new int[m];
  s=new long double[k];
  for (i=0; i<m; i++)
  fscanf(f,"%d%d%d%d",&pa[i].x,&pa[i].y,&pb[i].x,&pb[i].y);
  n=-1; c=0;
}
void TPlane::put(FILE*f) {
  int i;
  fprintf(f,"%d\n",c);
  for (i=0; i<c; i++) fprintf(f,"%.5Lf\n",s[i]);
}
int TPlane::resolve(TPoint*q) {
  int u,v,w;
  for (u=0,v=n; u<v; ) {
    w=(u+v)>>1;
    if ( (q->x<p[w].x) || ((q->x==p[w].x)&&(q->y<=p[w].y)) ) v=w;
    else u=w+1;
  }
  return(u);
}
void TPlane::sortsift(int u,int v) {
  int i,j; TPoint z;
  i=u; j=(i<<1)+1;
  if ((j<v)&&(TPointLWR(pz[j],pz[j+1]))) j++;
  z=pz[i];
  while ((j<=v)&&(TPointLWR(z,pz[j]))) {
    pz[i]=pz[j];
    i=j; j=(i<<1)+1;
    if ((j<v)&&(TPointLWR(pz[j],pz[j+1]))) j++;
  }
  pz[i]=z;
}
void TPlane::sort(void) {
  int i,j; TPoint z;
  j=k-1; for (i=k>>1; i>=0; i--) sortsift(i,j);
  i=0; while (j>0) {
    z=pz[i]; pz[i]=pz[j]; pz[j]=z;
    j--;
    sortsift(i,j);
  }
}
void TPlane::tranzlate(void) {
  if (!m) { n=0; return; }
  int i,j;
  for (i=0,j=0; i<m; i++,j+=2) { pz[j]=pa[i]; pz[j+1]=pb[i]; }
  sort();
  p[0]=pz[0]; n=1;
  for (i=1; i<k; i++) {
    if ((pz[i].x!=pz[i-1].x)||(pz[i].y!=pz[i-1].y)) p[n++]=pz[i];
  }
  for (i=0; i<m; i++) {
    a[i]=resolve(&pa[i]);
    b[i]=resolve(&pb[i]);
  }
}

TGraph::TGraph(void) {
  e=0; a=0;
  f=q=0;
  d=r=s=0;
  t=0;
}
TGraph::~TGraph() {
  if (e) delete[]e; if (a) delete[]a;
  if (f) delete[]f; if (q) delete[]q;
  if (d) delete[]d; if (r) delete[]r; if (s) delete[]s;
  if (t) delete[]t;
}
void TGraph::get(TPlane*p) {
  if (e) delete[]e; if (a) delete[]a;
  if (f) delete[]f; if (q) delete[]q;
  if (d) delete[]d; if (r) delete[]r; if (s) delete[]s;
  if (t) delete[]t;
  if (p->n<0) p->tranzlate();
  int i;
  k=p->m<<1; n=p->n;
  e=new TEdge[k]; a=new TEdge*[n];
  f=new int[n]; q=new int[n];
  d=new int[n]; r=new int[n]; s=new int[n];
  t=new int[n<<1];
  m=0;
  for (i=0; i<n; i++) a[i]=0;
  for (i=0; i<p->m; i++) {
    e[m].b=p->b[i]; e[m].z=a[p->a[i]]; a[p->a[i]]=&e[m++];
    e[m].b=p->a[i]; e[m].z=a[p->b[i]]; a[p->b[i]]=&e[m++];
  }
}
void TGraph::put(TPlane*p) {
  int i;
  for (i=0; i<n; i++) f[i]=1;
  for (i=0; i<n; i++) { seek(p,i); f[i]--; }
}

