{$I+,Q+,R+,S+}
program         Template;

uses
  Math;

type
  TSegment      = record
    X1, Y1      : Integer;
    X2, Y2      : Integer;
  end;

  TCoord        = record
    X, Y        : Integer;
  end;

  PVertex       = ^TVertex;
  TVertex       = record
    Y, U        : Integer;
    Next        : PVertex;
  end;

  PEdge         = ^TEdge;
  TEdge         = record
    A, B        : Integer;
    L, R        : Integer;
    Next        : PEdge;
  end;

var
  N, V, C       : Integer;
  Segments      : array[1..5000] of TSegment;
  Vertices      : array[-10000..10000] of PVertex;
  Coords        : array[1..10000] of TCoord;
  Power         : array[1..10000] of Integer;
  Edges         : array[1..10000] of PEdge;
  Count         : Integer;
  Colors        : array[1..10000] of Integer;
  Area          : array[1..10000] of Extended;
  Start         : Integer;

procedure       OpenFiles;
begin
  Assign(Input, 'input.txt');
  Reset(Input);
  Assign(Output, 'output.txt');
  Rewrite(Output);
end;

procedure       CloseFiles;
begin
  Close(Input);
  Close(Output);
end;

procedure       ReadData;
var
  I             : Integer;
begin
  ReadLn(N);
  if N = 0 then begin
    Writeln(0);
    CloseFiles;
    Halt;
  end;

  for I := 1 to N do
    ReadLn(Segments[I].X1, Segments[I].Y1, Segments[I].X2, Segments[I].Y2);
end;

(* ஥  *********************************************************)

function        FindPoint(X, Y: Integer): Integer;
var
  Vert          : PVertex;
begin
  Vert := Vertices[X];
  while Vert^.Y <> Y do
    Vert := Vert^.Next;

  FindPoint := Vert^.U;
end;

procedure       AddPoint(X, Y: Integer);
var
  Vert, NewVert : PVertex;
  LastVert      : PVertex;
begin
  if Vertices[X] <> nil then begin
    Vert := Vertices[X]; LastVert := nil;
    while (Vert <> nil) and (Vert^.Y < Y) do begin
      LastVert := Vert;
      Vert := Vert^.Next;
    end;

    if Vert = nil then begin
      Inc(V);

      New(NewVert);
      NewVert^.Y := Y;
      NewVert^.U := V;
      NewVert^.Next := nil;

      LastVert^.Next := NewVert;

      Coords[V].X := X;
      Coords[V].Y := Y;
    end else if Vert^.Y > Y then begin
      Inc(V);

      New(NewVert);
      NewVert^.Y := Y;
      NewVert^.U := V;
      NewVert^.Next := Vert;

      if LastVert <> nil then
        LastVert^.Next := NewVert
      else
        Vertices[X] := NewVert;

      Coords[V].X := X;
      Coords[V].Y := Y;
    end;
  end else begin
    Inc(V);

    New(Vertices[X]);
    Vertices[X]^.Y := Y;
    Vertices[X]^.U := V;
    Vertices[X]^.Next := nil;

    Coords[V].X := X;
    Coords[V].Y := Y;
  end;
end;

procedure       AddFence(X1, Y1, X2, Y2: Integer);
var
  V1, V2        : Integer;
  Edge          : PEdge;
begin
  V1 := FindPoint(X1, Y1); Inc(Power[V1]);
  V2 := FindPoint(X2, Y2); Inc(Power[V2]);

  New(Edge);
  Edge^.A := V1;
  Edge^.B := V2;
  Edge^.L := -1;
  Edge^.R := -1;
  Edge^.Next := Edges[V1];
  Edges[V1] := Edge;

  New(Edge);
  Edge^.A := V2;
  Edge^.B := V1;
  Edge^.L := -1;
  Edge^.R := -1;
  Edge^.Next := Edges[V2];
  Edges[V2] := Edge;
end;

procedure       BuildGraph;
var
  I             : Integer;
begin
  V := 0; FillChar(Vertices, SizeOf(Vertices), 0);
  for I := 1 to N do begin
    AddPoint(Segments[I].X1, Segments[I].Y1);
    AddPoint(Segments[I].X2, Segments[I].Y2);
  end;

  FillChar(Power, SizeOf(Power), 0); FillChar(Edges, SizeOf(Edges), 0);
  for I := 1 to N do
    AddFence(Segments[I].X1, Segments[I].Y1, Segments[I].X2, Segments[I].Y2);
end;

(*   㡨 **********************************************************)

function        GetPolarAngle(Ang: Extended; DX, DY: Integer): Extended;
var
  Beta, Alpha   : Extended;
begin
  if DY <> 0 then
    Beta := ArcTan2(DY, DX)
  else
    if DY < 0 then
      Beta := -Pi / 2
    else
      Beta := Pi / 2;

  Alpha := Beta - Ang;
  if Alpha < -Pi then
    Alpha := 2 * Pi + Alpha;

  GetPolarAngle := Alpha;
end;

procedure       DFS(LE: PEdge; U: Integer; Ang: Extended; First: Boolean; var Finish: Boolean);
var
  E, EE         : PEdge;
  A, Lang      : Extended;
label
  aaaa;
begin
  E := Edges[U];
  if First then
    LAng := -Pi
  else
    LAng := +Pi;

  repeat
    EE := nil;
    while E <> nil do begin
      if (E^.B = Start) then
        if (LE^.A <> Start) then begin
          EE := E;
          Break;
        end else
          goto aaaa;

      if (E^.L < 0) and (E^.R < 0) then begin
        A := GetPolarAngle(Ang, Coords[E^.B].X - Coords[U].X, Coords[E^.B].Y - Coords[U].Y);
        if First then begin
          if A = +Pi then
            A := -Pi;

          if A > LAng then begin
            LAng := A;
            EE := E
          end;
        end else begin
          if A = -Pi then
            A := +Pi;

          if A < LAng then begin
            LAng := A;
            EE := E
          end;
        end;
      end;

aaaa:      E := E^.Next;
    end;

    if EE = nil then begin
      if LE <> nil then begin
        LE^.R := C;
        LE^.L := C;
      end;

      Finish := False;
      Exit;
    end else begin
      if LE <> nil then
        LE^.R := C;

      if EE^.B = Start then begin
        Finish := True;
        EE^.R := C;

        Area[C] := Area[C] + (Coords[EE^.B].X - Coords[U].X) * (Coords[EE^.B].Y + Coords[U].Y) / 2;

        Exit;
      end;

      DFS(EE, EE^.B, ArcTan2(Coords[EE^.B].Y - Coords[U].Y, Coords[EE^.B].X - Coords[U].X), False, Finish);
      if Finish then begin
        Area[C] := Area[C] + (Coords[EE^.B].X - Coords[U].X) * (Coords[EE^.B].Y + Coords[U].Y) / 2;
        Exit;
      end;
    end;
  until False;
end;

procedure       Solve;
var
  I, K          : Integer;
  Finish        : Boolean;
  Lang          : Extended;
begin
  BuildGraph;

  Count := 0; FillChar(Colors, SizeOf(Colors), 0); C := 0;
  FillChar(Area, SizeOf(Area), 0);
  I := 1;
  repeat
    Start := I;
    repeat
      Inc(C);
      Finish := False; Lang := 0;
      DFS(nil, I, 0, True, Finish);
    until not Finish;
    Inc(I);
  until True;

  K := C;
  for I := 1 to C do
    if Area[I] = 0 then
      Dec(K);

  WriteLn(K - 1);
  for I := 1 to K - 1 do
    if Area[I] <> 0 then
      WriteLn(Abs(Area[I]):0:6);
end;

begin
  OpenFiles;
  ReadData;
  Solve;
  CloseFiles;
end.
