{$I+,Q-,R-,S+}
program         Template;

const
  QC_STATEMENT  = 1;
  QC_QUESTION   = 2;
  QC_INSULT     = 3;

  QSC_CHECK     = 1;
  QSC_SUBJECTS  = 2;
  QSC_ACTIONS   = 3;

  QS_SOMEBODY   = 0;
  QS_EVERYBODY  = 1;
  QS_NOBODY     = 2;
  QS_I          = 3;
  QS_YOU        = 4;

  REL_UNKNOWN   = 0;
  REL_POSITIVE  = 1;
  REL_NEGATIVE  = 2;
  REL_BOTH      = 3;

var
  SubjectCount  : Integer;
  ActionCount   : Integer;

  Subjects      : array[0..125] of string;              {            }
  Plural        : array[0..125] of Boolean;             { . ᫮?  }

  Actions       : array[1..125] of string;              {         }
  Objects       : array[1..125] of string;              {     }

  Graph         : array[1..125, 1..125] of Byte;

  qClass        : Integer;                              { ⨯    }
  qSubclass     : Integer;                              { ⨯    }
  qSubject      : string;                               { ꥪ       }
  qAction       : string;                               {         }
  qObject       : string;                               {     }
  qPlural       : Boolean;                              { ?         }
  qNegative     : Boolean;                              { 栭?    }

  WeirdData     : Boolean;                              { ਢ Input? }

(*  *********************************************************************)

procedure       Init;
begin
  FillChar(Subjects, SizeOf(Subjects), 0);
  FillChar(Plural, SizeOf(Plural), 0);

  FillChar(Actions, SizeOf(Actions), 0);
  FillChar(Objects, SizeOf(Objects), 0);

  FillChar(Graph, SizeOf(Graph), 0);

  SubjectCount          := 4;
  ActionCount           := 0;

  WeirdData             := False;

  Subjects[QS_I]        := 'I';
  Subjects[QS_YOU]      := 'you';

  Plural[QS_I]          := True;
  Plural[QS_YOU]        := True;
end;

(*  ⢥ত, ᮢ  㣠⥫ *******************************)

function        ExtractWord(var Phrase: string; Terminator: Char): string;
var
  P             : Integer;
begin
  P := Pos(Terminator, Phrase);
  if P > 0 then begin
    ExtractWord := Copy(Phrase, 1, P - 1);
    Delete(Phrase, 1, P);
  end else begin
    ExtractWord := Phrase;
    Phrase := '';
  end;
end;

procedure       ParseStatement(Phrase: string);
var
  I             : Integer;
begin
  Insert(' ', Phrase, Length(Phrase));

  qNegative     := False;
  qSubject      := ExtractWord(Phrase, ' ');
  qAction       := ExtractWord(Phrase, ' ');
  if (qAction = 'don''t') or (qAction = 'doesn''t') then begin
    qNegative   := True;
    qAction     := ExtractWord(Phrase, ' ');
  end;
  qObject       := Copy(Phrase, 1, Length(Phrase) - 2);
  qPlural       := qSubject[Length(qSubject)] = 's';
end;

procedure       ParseQuestion(Phrase: string);
var
  Word          : string;
begin
  Insert(' ', Phrase, Length(Phrase));

  Word := ExtractWord(Phrase, ' ');
  if (Word = 'do') or (Word = 'does') then begin
    qSubclass   := QSC_CHECK;
    qSubject    := ExtractWord(Phrase, ' ');
    qAction     := ExtractWord(Phrase, ' ');
    qObject     := Copy(Phrase, 1, Length(Phrase) - 2);
    qPlural     := Word = 'do';
    qNegative   := False;
  end else if Word = 'who' then begin
    qSubclass   := QSC_SUBJECTS;
    qSubject    := 'N/A';
    qAction     := ExtractWord(Phrase, ' ');
    qObject     := Copy(Phrase, 1, Length(Phrase) - 2);
    qPlural     := False;
    qNegative   := False;

    Delete(qAction, Length(qAction), 1);
  end else if Word = 'what' then begin
    qSubclass   := QSC_ACTIONS;
    qPlural     := ExtractWord(Phrase, ' ') = 'do';
    qSubject    := ExtractWord(Phrase, ' ');
    qAction     := 'N/A';
    qObject     := 'N/A';
    qNegative   := False;
  end;
end;

procedure       ParseInput;
var
  Phrase        : string;
begin
  ReadLn(Phrase);

  case Phrase[Length(Phrase)] of
    '.': begin
      qClass := QC_STATEMENT;
      ParseStatement(Phrase);
    end;
    '?': begin
      qClass := QC_QUESTION;
      ParseQuestion(Phrase);
    end;
    '!':
      qClass := QC_INSULT;
  end;
end;

(*   䮬 **********************************************************)

function        RegisterSubject(ASubject: string; IsPlural: Boolean): Integer;
var
  ID            : Integer;
begin
  ID := 5;

  if ASubject = 'I' then
    ASubject := 'you' //ID := QS_YOU
  else if ASubject = 'you' then
    ASubject := 'I' //ID := QS_I
  else if ASubject = 'everybody' then
    ID := QS_EVERYBODY
  else if ASubject = 'nobody' then
    ID := QS_NOBODY;

  if (ASubject = 'I') or (ASubject = 'you') then
    IsPlural := True;

  if ID = 5 then begin
    while (ID <= SubjectCount) and (Subjects[ID] <> ASubject) do
      Inc(ID);

    if ID > SubjectCount then begin
      Inc(SubjectCount);

      Subjects[ID] := ASubject;
      Plural[ID] := IsPlural;
    end;
  end;

  RegisterSubject := ID;
end;

function        RegisterAction(AAction, AObject: string): Integer;
var
  ID            : Integer;
begin
  if AAction[Length(AAction)] = 's' then
    Delete(AAction, Length(AAction), 1);

  ID := 0;
  while (ID <= ActionCount) and ((Actions[ID] <> AAction) or (Objects[ID] <> AObject)) do
    Inc(ID);

  if ID > ActionCount then begin
    Inc(ActionCount);

    Actions[ID] := AAction;
    Objects[ID] := AObject;
  end;

  RegisterAction := ID;
end;

function        ReverseSubject(ASubject: string): string;
begin
  if ASubject = 'I' then
    ReverseSubject := 'you'
  else if ASubject = 'you' then
    ReverseSubject := 'I'
  else
    ReverseSubject := ASubject;
end;

(* 믮  *******************************************************)

procedure       ProcessStatement;
var
  SID, AID, Rel : Integer;
begin
  SID := RegisterSubject(qSubject, qPlural);
  AID := RegisterAction(qAction, qObject);

  if qNegative then
    Rel := REL_NEGATIVE
  else
    Rel := REL_POSITIVE;

  if SID = QS_EVERYBODY then begin
    if Graph[QS_NOBODY, AID] <> REL_UNKNOWN then
      WeirdData := True
    else if (Graph[QS_SOMEBODY, AID] = REL_NEGATIVE) or (Graph[QS_SOMEBODY, AID] = REL_BOTH) then
      WeirdData := True
    else begin
      Graph[SID, AID] := Rel;
      Graph[QS_SOMEBODY, AID] := REL_POSITIVE;
    end;
  end else if SID = QS_NOBODY then begin
    if Graph[QS_EVERYBODY, AID] <> REL_UNKNOWN then
      WeirdData := True
    else if (Graph[QS_SOMEBODY, AID] = REL_POSITIVE) or (Graph[QS_SOMEBODY, AID] = REL_BOTH) then
      WeirdData := True
    else begin
      Graph[SID, AID] := Rel;
      Graph[QS_SOMEBODY, AID] := REL_NEGATIVE;
    end;
  end else begin
    if (Graph[SID, AID] <> REL_UNKNOWN) and (Graph[SID, AID] <> Rel) then
      WeirdData := True
    else if (Graph[QS_EVERYBODY, AID] <> REL_UNKNOWN) and (Rel = REL_NEGATIVE) then
      WeirdData := True
    else if (Graph[QS_NOBODY, AID] <> REL_UNKNOWN) and (Rel = REL_POSITIVE) then
      WeirdData := True
    else begin
      Graph[SID, AID] := Rel;

      if Graph[QS_SOMEBODY, AID] = REL_UNKNOWN then
        Graph[QS_SOMEBODY, AID] := Rel
      else if Graph[QS_SOMEBODY, AID] <> Rel then
        Graph[QS_SOMEBODY, AID] := REL_BOTH;
    end;
  end;
end;

procedure       ProcessQuestion;
var
  SID, AID, Rel : Integer;
  I             : Integer;
  SIDCount      : Integer;
  SIDs          : array[1..125] of Integer;
  AIDCount      : Integer;
  AIDs          : array[1..250] of Integer;
begin
  if WeirdData then begin
    WriteLn('I am abroad.');
    Exit;
  end;

  if qSubject <> 'N/A' then
    SID := RegisterSubject(qSubject, qPlural);
  if qAction <> 'N/A' then
    AID := RegisterAction(qAction, qObject);

  if qSubclass = QSC_CHECK then begin
    Rel := REL_UNKNOWN;

    if Graph[SID, AID] <> REL_UNKNOWN then
      Rel := Graph[SID, AID]
    else if Graph[QS_EVERYBODY, AID] <> REL_UNKNOWN then
      Rel := REL_POSITIVE
    else if Graph[QS_NOBODY, AID] <> REL_UNKNOWN then
      Rel := REL_NEGATIVE;

    if Rel = REL_UNKNOWN then
      WriteLn('maybe.')
    else begin
      if Rel = REL_POSITIVE then
        Write('yes, ')
      else
        Write('no, ');

      Write(ReverseSubject(qSubject), ' ');

      if Rel = REL_NEGATIVE then
        if qPlural then
          Write('don''t ')
        else
          Write('doesn''t ');

      Write(qAction);
      if (Rel = REL_POSITIVE) and not qPlural then
        Write('s');

      if qObject <> '' then
        Write(' ', qObject);

      WriteLn('.');
    end;
  end else if qSubclass = QSC_SUBJECTS then begin
    if Graph[QS_EVERYBODY, AID] <> REL_UNKNOWN then begin
      Write('everybody ', Actions[AID], 's');

      if Objects[AID] <> '' then
        Write(' ', Objects[AID]);

      WriteLn('.');
    end else if Graph[QS_NOBODY, AID] <> REL_UNKNOWN then begin
      Write('nobody ', Actions[AID], 's');

      if Objects[AID] <> '' then
        Write(' ', Objects[AID]);

      WriteLn('.');
    end else begin
      SIDCount := 0;
      for I := 1 to SubjectCount do
        if Graph[I, AID] = REL_POSITIVE then begin
          Inc(SIDCount);
          SIDs[SIDCount] := I;
        end;

      if SIDCount = 0 then
        WriteLn('I don''t know.')
      else begin
        for I := 1 to SIDCount do begin
          Write(Subjects[SIDs[I]]);

          if I < SIDCount then
            if I < SIDCount - 1 then
              Write(', ')
            else
              Write(' and ');
        end;

        Write(' ', Actions[AID]);
        if (SIDCount = 1) and not Plural[SIDS[1]] then
          Write('s');

        if Objects[AID] <> '' then
          Write(' ', Objects[AID]);

        WriteLn('.');
      end;
    end;
  end else if qSubclass = QSC_ACTIONS then begin
    AIDCount := 0;
    for I := 1 to ActionCount do
      if Graph[QS_EVERYBODY, I] <> REL_UNKNOWN then begin
        Inc(AIDCount);
        AIDs[AIDCount] := I;
      end else if Graph[QS_NOBODY, I] <> REL_UNKNOWN then begin
        Inc(AIDCount);
        AIDs[AIDCount] := -I;
      end else if Graph[SID, I] = REL_POSITIVE then begin
        Inc(AIDCount);
        AIDs[AIDCount] := I;
      end else if Graph[SID, I] = REL_NEGATIVE then begin
        Inc(AIDCount);
        AIDs[AIDCount] := -I;
      end;

    if AIDCount = 0 then
      WriteLn('I don''t know.')
    else begin
      Write(Subjects[SID], ' '); qPlural := Plural[SID];
      for I := 1 to AIDCount do begin
        if AIDs[I] < 0 then
          if qPlural then
            Write('don''t ')
          else
            Write('doesn''t ');

        Write(Actions[Abs(AIDs[I])]);
        if (AIDs[I] > 0) and not qPlural then
          Write('s');

        if Objects[Abs(AIDs[I])] <> '' then
          Write(' ', Objects[Abs(AIDs[I])]);

        if I < AIDCount then
          if I < AIDCount - 1 then
            Write(', ')
          else
            Write(', and ');
      end;

      WriteLn('.');
    end;
  end;
end;

function        Process: Boolean;
begin
  Process := True;
  case qClass of
    QC_STATEMENT:
      ProcessStatement;
    QC_QUESTION:
      ProcessQuestion;
    QC_INSULT:
      Process := False;
  end;

  Flush(Output);
end;

begin
  Init;
  repeat
    ParseInput;
  until not Process;
end.
